@@ -6,6 +6,7 @@ package multi_env_app_test
 import (
 	"fmt"
 	"net/http"
+	"os"
 
 	. "github.com/onsi/ginkgo"
 	. "github.com/onsi/gomega"
@@ -93,9 +94,11 @@ var _ = Describe("Multiple Env App", func() {
 			Expect(envs["prod"].Prod).To(BeTrue())
 
 			// Make sure, for the sake of coverage, these are cross account,
-			// cross region environments.
-			Expect(envs["test"].Region).NotTo(Equal(envs["prod"].Region))
-			Expect(envs["test"].Account).NotTo(Equal(envs["prod"].Account))
+			// cross region environments if we're not doing a dryrun.
+			if os.Getenv("DRYRUN") != "true" {
+				Expect(envs["test"].Region).NotTo(Equal(envs["prod"].Region))
+				Expect(envs["test"].Account).NotTo(Equal(envs["prod"].Account))
+			}
 		})
 	})
 
@@ -241,8 +244,10 @@ var _ = Describe("Multiple Env App", func() {
 			Expect(envs["test"].Prod).To(BeFalse())
 			Expect(envs["prod"]).NotTo(BeNil())
 			Expect(envs["prod"].Prod).To(BeTrue())
-			Expect(envs["test"].Region).NotTo(Equal(envs["prod"].Region))
-			Expect(envs["test"].Account).NotTo(Equal(envs["prod"].Account))
+			if os.Getenv("DRYRUN") != "true" {
+				Expect(envs["test"].Region).NotTo(Equal(envs["prod"].Region))
+				Expect(envs["test"].Account).NotTo(Equal(envs["prod"].Account))
+			}
 			Expect(envs["test"].ExecutionRole).NotTo(Equal(envs["prod"].ExecutionRole))
 			Expect(envs["test"].ManagerRole).NotTo(Equal(envs["prod"].ExecutionRole))
 		})
