@@ -280,7 +280,7 @@ func TestEC2_ListVPCSubnets(t *testing.T) {
 			},
 			wantedError: fmt.Errorf("describe subnets: some error"),
 		},
-		"success": {
+		"can retrieve subnets explicitly associated with an internet gateway": {
 			mockEC2Client: func(m *mocks.Mockapi) {
 				m.EXPECT().DescribeRouteTables(&ec2.DescribeRouteTablesInput{
 					Filters: mockfilter,
@@ -372,6 +372,145 @@ func TestEC2_ListVPCSubnets(t *testing.T) {
 				},
 			},
 		},
+		"can retrieve subnets that are implicitly associated with an internet gateway": {
+			mockEC2Client: func(m *mocks.Mockapi) {
+				m.EXPECT().DescribeRouteTables(&ec2.DescribeRouteTablesInput{
+					Filters: mockfilter,
+				}).Return(&ec2.DescribeRouteTablesOutput{
+					RouteTables: []*ec2.RouteTable{
+						{
+							Associations: []*ec2.RouteTableAssociation{
+								{
+									Main: aws.Bool(true),
+								},
+							},
+							Routes: []*ec2.Route{
+								{
+									GatewayId:            aws.String("local"),
+									DestinationCidrBlock: aws.String("172.31.0.0/16"),
+								},
+								{
+									GatewayId:            aws.String("igw-3542f24c"),
+									DestinationCidrBlock: aws.String("0.0.0.0/0"),
+								},
+							},
+						},
+					},
+				}, nil)
+
+				m.EXPECT().DescribeSubnets(&ec2.DescribeSubnetsInput{
+					Filters: mockfilter,
+				}).Return(&ec2.DescribeSubnetsOutput{
+					Subnets: []*ec2.Subnet{
+						{
+							SubnetId:  aws.String("subnet1"),
+							CidrBlock: aws.String("172.31.16.0/20"),
+						},
+						{
+							SubnetId:  aws.String("subnet2"),
+							CidrBlock: aws.String("172.31.48.0/20"),
+						},
+						{
+							SubnetId:  aws.String("subnet3"),
+							CidrBlock: aws.String("172.31.32.0/20"),
+						},
+					},
+				}, nil)
+			},
+			wantedPublicSubnets: []Subnet{
+				{
+					Resource: Resource{
+						ID: "subnet1",
+					},
+					CIDRBlock: "172.31.16.0/20",
+				},
+				{
+					Resource: Resource{
+						ID: "subnet2",
+					},
+					CIDRBlock: "172.31.48.0/20",
+				},
+				{
+					Resource: Resource{
+						ID: "subnet3",
+					},
+					CIDRBlock: "172.31.32.0/20",
+				},
+			},
+			wantedPrivateSubnets: nil,
+		},
+		"prioritizes explicit route table association over implicit while detecting public subnets": {
+			mockEC2Client: func(m *mocks.Mockapi) {
+				m.EXPECT().DescribeRouteTables(&ec2.DescribeRouteTablesInput{
+					Filters: mockfilter,
+				}).Return(&ec2.DescribeRouteTablesOutput{
+					RouteTables: []*ec2.RouteTable{
+						{
+							Associations: []*ec2.RouteTableAssociation{
+								{
+									Main:     aws.Bool(false),
+									SubnetId: aws.String("subnet1"),
+								},
+							},
+							Routes: []*ec2.Route{
+								{
+									GatewayId:            aws.String("local"),
+									DestinationCidrBlock: aws.String("172.31.0.0/16"),
+								},
+							},
+						},
+						{
+							Associations: []*ec2.RouteTableAssociation{
+								{
+									Main: aws.Bool(true),
+								},
+							},
+							Routes: []*ec2.Route{
+								{
+									GatewayId:            aws.String("local"),
+									DestinationCidrBlock: aws.String("172.31.0.0/16"),
+								},
+								{
+									GatewayId:            aws.String("igw-3542f24c"),
+									DestinationCidrBlock: aws.String("0.0.0.0/0"),
+								},
+							},
+						},
+					},
+				}, nil)
+
+				m.EXPECT().DescribeSubnets(&ec2.DescribeSubnetsInput{
+					Filters: mockfilter,
+				}).Return(&ec2.DescribeSubnetsOutput{
+					Subnets: []*ec2.Subnet{
+						{
+							SubnetId:  aws.String("subnet1"),
+							CidrBlock: aws.String("172.31.16.0/20"),
+						},
+						{
+							SubnetId:  aws.String("subnet2"),
+							CidrBlock: aws.String("172.31.48.0/20"),
+						},
+					},
+				}, nil)
+			},
+			wantedPublicSubnets: []Subnet{
+				{
+					Resource: Resource{
+						ID: "subnet2",
+					},
+					CIDRBlock: "172.31.48.0/20",
+				},
+			},
+			wantedPrivateSubnets: []Subnet{
+				{
+					Resource: Resource{
+						ID: "subnet1",
+					},
+					CIDRBlock: "172.31.16.0/20",
+				},
+			},
+		},
 	}
 
 	for name, tc := range testCases {
