@@ -326,7 +326,8 @@ func NewLBDeployer(in *WorkloadDeployerInput) (*lbSvcDeployer, error) {
 
 type backendSvcDeployer struct {
 	*svcDeployer
-	backendMft *manifest.BackendService
+	backendMft         *manifest.BackendService
+	aliasCertValidator aliasCertValidator
 }
 
 // IsServiceAvailableInRegion checks if service type exist in the given region.
@@ -345,8 +346,9 @@ func NewBackendDeployer(in *WorkloadDeployerInput) (*backendSvcDeployer, error)
 		return nil, fmt.Errorf("manifest is not of type %s", manifest.BackendServiceType)
 	}
 	return &backendSvcDeployer{
-		svcDeployer: svcDeployer,
-		backendMft:  bsMft,
+		svcDeployer:        svcDeployer,
+		backendMft:         bsMft,
+		aliasCertValidator: acm.New(svcDeployer.envSess),
 	}, nil
 }
 
@@ -942,7 +944,16 @@ func (d *backendSvcDeployer) stackConfiguration(in *StackRuntimeConfiguration) (
 	if err != nil {
 		return nil, err
 	}
-	conf, err := stack.NewBackendService(d.backendMft, d.env.Name, d.app.Name, *rc)
+	if err := d.validateALBRuntime(); err != nil {
+		return nil, err
+	}
+
+	conf, err := stack.NewBackendService(stack.BackendServiceConfig{
+		App:           d.app,
+		Env:           d.env,
+		Manifest:      d.backendMft,
+		RuntimeConfig: *rc,
+	})
 	if err != nil {
 		return nil, fmt.Errorf("create stack configuration: %w", err)
 	}
@@ -1197,6 +1208,34 @@ func validateAppVersionForAlias(appName string, appVersionGetter versionGetter)
 	return nil
 }
 
+func (d *backendSvcDeployer) validateALBRuntime() error {
+	if d.backendMft.RoutingRule.IsEmpty() {
+		return nil
+	}
+	switch {
+	case d.backendMft.RoutingRule.Alias.IsEmpty() && d.env.HasImportedCerts():
+		return &errSvcWithNoALBAliasDeployingToEnvWithImportedCerts{
+			name:    d.name,
+			envName: d.env.Name,
+		}
+	case d.backendMft.RoutingRule.Alias.IsEmpty():
+		return nil
+	case !d.env.HasImportedCerts():
+		return fmt.Errorf(`cannot specify "alias" in an environment without imported certs`)
+	}
+
+	aliases, err := d.backendMft.RoutingRule.Alias.ToStringSlice()
+	if err != nil {
+		return fmt.Errorf("convert aliases to string slice: %w", err)
+	}
+
+	if err := d.aliasCertValidator.ValidateCertAliases(aliases, d.env.CustomConfig.ImportCertARNs); err != nil {
+		return fmt.Errorf("validate aliases against the imported certificate for env %s: %w", d.env.Name, err)
+	}
+
+	return nil
+}
+
 func (d *lbSvcDeployer) validateALBWSRuntime() error {
 	if d.lbMft.RoutingRule.Alias.IsEmpty() {
 		if d.env.HasImportedCerts() {
