@@ -263,7 +263,19 @@ func TestWorkloadDeployer_DeployWorkload(t *testing.T) {
 		mockName     = "mockWkld"
 		mockS3Bucket = "mockBucket"
 	)
-	mockAliases := []string{"example.com", "foobar.com"}
+	mockMultiAliases := []manifest.AdvancedAlias{
+		{
+			Alias: aws.String("example.com"),
+		},
+		{
+			Alias: aws.String("foobar.com"),
+		},
+	}
+	mockAlias := []manifest.AdvancedAlias{
+		{
+			Alias: aws.String("mockAlias"),
+		},
+	}
 	mockCertARNs := []string{"mockCertARN"}
 	mockResources := &stack.AppRegionalResources{
 		S3Bucket: mockS3Bucket,
@@ -314,14 +326,14 @@ func TestWorkloadDeployer_DeployWorkload(t *testing.T) {
 				},
 			},
 			inAliases: manifest.Alias{
-				StringSlice: mockAliases,
+				AdvancedAliases: mockMultiAliases,
 			},
 			inApp: &config.Application{
 				Name: mockAppName,
 			},
 			mock: func(m *deployMocks) {
 				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
-				m.mockValidator.EXPECT().ValidateCertAliases(mockAliases, mockCertARNs).Return(mockError)
+				m.mockValidator.EXPECT().ValidateCertAliases([]string{"example.com", "foobar.com"}, mockCertARNs).Return(mockError)
 			},
 			wantErr: fmt.Errorf("validate aliases against the imported certificate for env mockEnv: some error"),
 		},
@@ -343,7 +355,7 @@ func TestWorkloadDeployer_DeployWorkload(t *testing.T) {
 			wantErr: fmt.Errorf("get public CIDR blocks information from the VPC of environment mockEnv: some error"),
 		},
 		"alias used while app is not associated with a domain": {
-			inAliases: manifest.Alias{String: aws.String("mockAlias")},
+			inAliases: manifest.Alias{AdvancedAliases: mockAlias},
 			inEnvironment: &config.Environment{
 				Name:   mockEnvName,
 				Region: "us-west-2",
@@ -359,7 +371,7 @@ func TestWorkloadDeployer_DeployWorkload(t *testing.T) {
 		"nlb alias used while app is not associated with a domain": {
 			inNLB: manifest.NetworkLoadBalancerConfiguration{
 				Port:    aws.String("80"),
-				Aliases: manifest.Alias{String: aws.String("mockAlias")},
+				Aliases: manifest.Alias{AdvancedAliases: mockAlias},
 			},
 			inEnvironment: &config.Environment{
 				Name:   mockEnvName,
@@ -374,10 +386,10 @@ func TestWorkloadDeployer_DeployWorkload(t *testing.T) {
 			wantErr: errors.New("cannot specify nlb.alias when application is not associated with a domain"),
 		},
 		"nlb alias used while env has imported certs": {
-			inAliases: manifest.Alias{String: aws.String("mockAlias")},
+			inAliases: manifest.Alias{AdvancedAliases: mockAlias},
 			inNLB: manifest.NetworkLoadBalancerConfiguration{
 				Port:    aws.String("80"),
-				Aliases: manifest.Alias{String: aws.String("mockAlias")},
+				Aliases: manifest.Alias{AdvancedAliases: mockAlias},
 			},
 			inEnvironment: &config.Environment{
 				Name:   mockEnvName,
@@ -396,7 +408,7 @@ func TestWorkloadDeployer_DeployWorkload(t *testing.T) {
 			wantErr: errors.New("cannot specify nlb.alias when env mockEnv imports one or more certificates"),
 		},
 		"fail to get app version": {
-			inAliases: manifest.Alias{String: aws.String("mockAlias")},
+			inAliases: manifest.Alias{AdvancedAliases: mockAlias},
 			inEnvironment: &config.Environment{
 				Name:   mockEnvName,
 				Region: "us-west-2",
@@ -412,7 +424,7 @@ func TestWorkloadDeployer_DeployWorkload(t *testing.T) {
 			wantErr: fmt.Errorf("get version for app %s: %w", mockAppName, mockError),
 		},
 		"fail to enable https alias because of incompatible app version": {
-			inAliases: manifest.Alias{String: aws.String("mockAlias")},
+			inAliases: manifest.Alias{AdvancedAliases: mockAlias},
 			inEnvironment: &config.Environment{
 				Name:   mockEnvName,
 				Region: "us-west-2",
@@ -430,7 +442,7 @@ func TestWorkloadDeployer_DeployWorkload(t *testing.T) {
 		"fail to enable nlb alias because of incompatible app version": {
 			inNLB: manifest.NetworkLoadBalancerConfiguration{
 				Port:    aws.String("80"),
-				Aliases: manifest.Alias{String: aws.String("mockAlias")},
+				Aliases: manifest.Alias{AdvancedAliases: mockAlias},
 			},
 			inEnvironment: &config.Environment{
 				Name:   mockEnvName,
@@ -447,7 +459,9 @@ func TestWorkloadDeployer_DeployWorkload(t *testing.T) {
 			wantErr: fmt.Errorf("alias is not compatible with application versions below %s", deploy.AliasLeastAppTemplateVersion),
 		},
 		"fail to enable https alias because of invalid alias": {
-			inAliases: manifest.Alias{String: aws.String("v1.v2.mockDomain")},
+			inAliases: manifest.Alias{AdvancedAliases: []manifest.AdvancedAlias{
+				{Alias: aws.String("v1.v2.mockDomain")},
+			}},
 			inEnvironment: &config.Environment{
 				Name:   mockEnvName,
 				Region: "us-west-2",
@@ -464,8 +478,10 @@ func TestWorkloadDeployer_DeployWorkload(t *testing.T) {
 		},
 		"fail to enable nlb alias because of invalid alias": {
 			inNLB: manifest.NetworkLoadBalancerConfiguration{
-				Port:    aws.String("80"),
-				Aliases: manifest.Alias{String: aws.String("v1.v2.mockDomain")},
+				Port: aws.String("80"),
+				Aliases: manifest.Alias{AdvancedAliases: []manifest.AdvancedAlias{
+					{Alias: aws.String("v1.v2.mockDomain")},
+				}},
 			},
 			inEnvironment: &config.Environment{
 				Name:   mockEnvName,
@@ -606,7 +622,7 @@ func TestWorkloadDeployer_DeployWorkload(t *testing.T) {
 		},
 		"success": {
 			inAliases: manifest.Alias{
-				StringSlice: mockAliases,
+				AdvancedAliases: mockMultiAliases,
 			},
 			inEnvironment: &config.Environment{
 				Name:   mockEnvName,
@@ -621,7 +637,7 @@ func TestWorkloadDeployer_DeployWorkload(t *testing.T) {
 			},
 			mock: func(m *deployMocks) {
 				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
-				m.mockValidator.EXPECT().ValidateCertAliases(mockAliases, mockCertARNs).Return(nil)
+				m.mockValidator.EXPECT().ValidateCertAliases([]string{"example.com", "foobar.com"}, mockCertARNs).Return(nil)
 				m.mockServiceDeployer.EXPECT().DeployService(gomock.Any(), gomock.Any(), "mockBucket", gomock.Any()).Return(nil)
 			},
 		},
@@ -1103,3 +1119,184 @@ func Test_validateTopicsExist(t *testing.T) {
 		})
 	}
 }
+
+func TestBackendSvcDeployer_stackConfiguration(t *testing.T) {
+	const (
+		mockAppName = "mock-app"
+		mockEnvName = "mock-env"
+		mockSvcName = "mock-svc"
+	)
+
+	tests := map[string]struct {
+		App        *config.Application
+		Env        *config.Environment
+		Manifest   *manifest.BackendService
+		setupMocks func(m *deployMocks)
+
+		expectedErr string
+	}{
+		"success if alb not configured": {
+			App: &config.Application{
+				Name: mockAppName,
+			},
+			Env: &config.Environment{
+				Name: mockEnvName,
+			},
+			Manifest: &manifest.BackendService{},
+			setupMocks: func(m *deployMocks) {
+				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return(mockAppName+".local", nil)
+			},
+		},
+		"failure if alias configured, no env certs": {
+			App: &config.Application{
+				Name: mockAppName,
+			},
+			Env: &config.Environment{
+				Name: mockEnvName,
+			},
+			Manifest: &manifest.BackendService{
+				BackendServiceConfig: manifest.BackendServiceConfig{
+					RoutingRule: manifest.RoutingRuleConfiguration{
+						Alias: manifest.Alias{
+							AdvancedAliases: []manifest.AdvancedAlias{
+								{Alias: aws.String("go.dev")},
+							},
+						},
+					},
+				},
+			},
+			setupMocks: func(m *deployMocks) {
+				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return(mockAppName+".local", nil)
+			},
+			expectedErr: `cannot specify "alias" in an environment without imported certs`,
+		},
+		"failure if cert validation fails": {
+			App: &config.Application{
+				Name: mockAppName,
+			},
+			Env: &config.Environment{
+				Name: mockEnvName,
+				CustomConfig: &config.CustomizeEnv{
+					ImportCertARNs: []string{"mockCertARN"},
+				},
+			},
+			Manifest: &manifest.BackendService{
+				BackendServiceConfig: manifest.BackendServiceConfig{
+					RoutingRule: manifest.RoutingRuleConfiguration{
+						Alias: manifest.Alias{
+							AdvancedAliases: []manifest.AdvancedAlias{
+								{Alias: aws.String("go.dev")},
+							},
+						},
+					},
+				},
+			},
+			setupMocks: func(m *deployMocks) {
+				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return(mockAppName+".local", nil)
+				m.mockValidator.EXPECT().ValidateCertAliases([]string{"go.dev"}, []string{"mockCertARN"}).Return(errors.New("some error"))
+			},
+			expectedErr: "validate aliases against the imported certificate for env mock-env: some error",
+		},
+		"success if cert validation succeeds": {
+			App: &config.Application{
+				Name: mockAppName,
+			},
+			Env: &config.Environment{
+				Name: mockEnvName,
+				CustomConfig: &config.CustomizeEnv{
+					ImportCertARNs: []string{"mockCertARN"},
+				},
+			},
+			Manifest: &manifest.BackendService{
+				BackendServiceConfig: manifest.BackendServiceConfig{
+					RoutingRule: manifest.RoutingRuleConfiguration{
+						Alias: manifest.Alias{
+							AdvancedAliases: []manifest.AdvancedAlias{
+								{Alias: aws.String("go.dev")},
+							},
+						},
+					},
+				},
+			},
+			setupMocks: func(m *deployMocks) {
+				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return(mockAppName+".local", nil)
+				m.mockValidator.EXPECT().ValidateCertAliases([]string{"go.dev"}, []string{"mockCertARN"}).Return(nil)
+			},
+		},
+		"failure if env has imported certs but no alias set": {
+			App: &config.Application{
+				Name: mockAppName,
+			},
+			Env: &config.Environment{
+				Name: mockEnvName,
+				CustomConfig: &config.CustomizeEnv{
+					ImportCertARNs: []string{"mockCertARN"},
+				},
+			},
+			Manifest: &manifest.BackendService{
+				BackendServiceConfig: manifest.BackendServiceConfig{
+					RoutingRule: manifest.RoutingRuleConfiguration{
+						Path: aws.String("/"),
+					},
+				},
+			},
+			setupMocks: func(m *deployMocks) {
+				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return(mockAppName+".local", nil)
+			},
+			expectedErr: `cannot deploy service mock-svc without http.alias to environment mock-env with certificate imported`,
+		},
+		"success if env has imported certs but alb not configured": {
+			App: &config.Application{
+				Name: mockAppName,
+			},
+			Env: &config.Environment{
+				Name: mockEnvName,
+				CustomConfig: &config.CustomizeEnv{
+					ImportCertARNs: []string{"mockCertARN"},
+				},
+			},
+			Manifest: &manifest.BackendService{},
+			setupMocks: func(m *deployMocks) {
+				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return(mockAppName+".local", nil)
+			},
+		},
+	}
+
+	for name, tc := range tests {
+		t.Run(name, func(t *testing.T) {
+			ctrl := gomock.NewController(t)
+			defer ctrl.Finish()
+
+			m := &deployMocks{
+				mockEndpointGetter: mocks.NewMockendpointGetter(ctrl),
+				mockValidator:      mocks.NewMockaliasCertValidator(ctrl),
+			}
+			if tc.setupMocks != nil {
+				tc.setupMocks(m)
+			}
+
+			deployer := &backendSvcDeployer{
+				svcDeployer: &svcDeployer{
+					workloadDeployer: &workloadDeployer{
+						name:           mockSvcName,
+						app:            tc.App,
+						env:            tc.Env,
+						endpointGetter: m.mockEndpointGetter,
+					},
+					newSvcUpdater: func(f func(*session.Session) serviceForceUpdater) serviceForceUpdater {
+						return nil
+					},
+				},
+				backendMft:         tc.Manifest,
+				aliasCertValidator: m.mockValidator,
+			}
+
+			_, err := deployer.stackConfiguration(&StackRuntimeConfiguration{})
+			if tc.expectedErr != "" {
+				require.EqualError(t, err, tc.expectedErr)
+			} else {
+				require.NoError(t, err)
+			}
+		})
+	}
+}
