@@ -10,6 +10,8 @@ import (
 	"os"
 	"strings"
 
+	"github.com/dustin/go-humanize/english"
+
 	"github.com/aws/aws-sdk-go/service/ssm"
 
 	"github.com/aws/aws-sdk-go/aws"
@@ -141,10 +143,12 @@ type initEnvVars struct {
 	isProduction  bool   // True means retain resources even after deletion.
 	defaultConfig bool   // True means using default environment configuration.
 
-	importVPC   importVPCVars // Existing VPC resources to use instead of creating new ones.
-	adjustVPC   adjustVPCVars // Configure parameters for VPC resources generated while initializing an environment.
-	telemetry   telemetryVars // Configure observability and monitoring settings.
-	importCerts []string      // Addtional existing ACM certificates to use.
+	importVPC          importVPCVars // Existing VPC resources to use instead of creating new ones.
+	adjustVPC          adjustVPCVars // Configure parameters for VPC resources generated while initializing an environment.
+	telemetry          telemetryVars // Configure observability and monitoring settings.
+	importCerts        []string      // Addtional existing ACM certificates to use.
+	internalALBSubnets []string      // Subnets to be used for internal ALB placement.
+	allowVPCIngress    bool          // True means the env stack will create ingress to the internal ALB from ports 80/443.
 
 	tempCreds tempCredsVars // Temporary credentials to initialize the environment. Mutually exclusive with the profile.
 	region    string        // The region to create the environment in.
@@ -202,7 +206,7 @@ func newInitEnvOpts(vars initEnvVars) (*initEnvOpts, error) {
 			Profile: cfg,
 			Prompt:  prompter,
 		},
-		selApp:   selector.NewSelect(prompt.New(), store),
+		selApp:   selector.NewAppEnvSelector(prompt.New(), store),
 		uploader: template.New(),
 		appCFN:   deploycfn.New(defaultSession),
 		newS3: func(region string) (uploader, error) {
@@ -322,9 +326,11 @@ func (o *initEnvOpts) Execute() error {
 	}
 	env.Prod = o.isProduction
 	customizedEnv := config.CustomizeEnv{
-		ImportVPC:      o.importVPCConfig(),
-		VPCConfig:      o.adjustVPCConfig(),
-		ImportCertARNs: o.importCerts,
+		ImportVPC:                   o.importVPCConfig(),
+		VPCConfig:                   o.adjustVPCConfig(),
+		ImportCertARNs:              o.importCerts,
+		InternalALBSubnets:          o.internalALBSubnets,
+		EnableInternalALBVPCIngress: o.allowVPCIngress,
 	}
 	if !customizedEnv.IsEmpty() {
 		env.CustomConfig = &customizedEnv
@@ -368,6 +374,11 @@ func (o *initEnvOpts) validateCustomizedResources() error {
 	if (o.importVPC.isSet() || o.adjustVPC.isSet()) && o.defaultConfig {
 		return fmt.Errorf("cannot import or configure vpc if --%s is set", defaultConfigFlag)
 	}
+	if o.internalALBSubnets != nil && (o.adjustVPC.isSet() || o.defaultConfig) {
+		log.Error(`To specify internal ALB subnet placement, you must import existing resources, including subnets.
+For default config without subnet placement specification, Copilot will place the internal ALB in the generated private subnets.`)
+		return fmt.Errorf("subnets '%s' specified for internal ALB placement, but those subnets are not imported", strings.Join(o.internalALBSubnets, ", "))
+	}
 	if o.importVPC.isSet() {
 		// Allow passing in VPC without subnets, but error out early for too few subnets-- we won't prompt the user to select more of one type if they pass in any.
 		if len(o.importVPC.PublicSubnetIDs) == 1 {
@@ -376,6 +387,9 @@ func (o *initEnvOpts) validateCustomizedResources() error {
 		if len(o.importVPC.PrivateSubnetIDs) == 1 {
 			return fmt.Errorf("at least two private subnets must be imported")
 		}
+		if err := o.validateInternalALBSubnets(); err != nil {
+			return err
+		}
 	}
 	if o.adjustVPC.isSet() {
 		if len(o.adjustVPC.AZs) == 1 {
@@ -462,6 +476,10 @@ func (o *initEnvOpts) askCustomizedResources() error {
 	if o.adjustVPC.isSet() {
 		return o.askAdjustResources()
 	}
+	if o.internalALBSubnets != nil {
+		log.Infoln("Because you have designated subnets on which to place an internal ALB, you must import VPC resources.")
+		return o.askImportResources()
+	}
 	adjustOrImport, err := o.prompt.SelectOne(
 		envInitDefaultEnvConfirmPrompt, "",
 		envInitCustomizedEnvTypes,
@@ -566,7 +584,7 @@ be able to add them after this environment is created.
 	if len(o.importVPC.PublicSubnetIDs)+len(o.importVPC.PrivateSubnetIDs) == 0 {
 		return errors.New("VPC must have subnets in order to proceed with environment creation")
 	}
-	return nil
+	return o.validateInternalALBSubnets()
 }
 
 func (o *initEnvOpts) askAdjustResources() error {
@@ -700,14 +718,15 @@ func (o *initEnvOpts) deployEnv(app *config.Application,
 			Domain:              app.Domain,
 			AccountPrincipalARN: caller.RootUserARN,
 		},
-		Prod:                 o.isProduction,
 		AdditionalTags:       app.Tags,
 		CustomResourcesURLs:  customResourcesURLs,
 		ArtifactBucketARN:    artifactBucketARN,
 		ArtifactBucketKeyARN: artifactBucketKeyARN,
 		AdjustVPCConfig:      o.adjustVPCConfig(),
 		ImportCertARNs:       o.importCerts,
+		InternalALBSubnets:   o.internalALBSubnets,
 		ImportVPCConfig:      o.importVPCConfig(),
+		AllowVPCIngress:      o.allowVPCIngress,
 		Telemetry:            o.telemetry.toConfig(),
 		Version:              deploy.LatestEnvTemplateVersion,
 	}
@@ -715,7 +734,7 @@ func (o *initEnvOpts) deployEnv(app *config.Application,
 	if err := o.cleanUpDanglingRoles(o.appName, o.name); err != nil {
 		return err
 	}
-	if err := o.envDeployer.DeployAndRenderEnvironment(os.Stderr, deployEnvInput); err != nil {
+	if err := o.envDeployer.CreateAndRenderEnvironment(os.Stderr, deployEnvInput); err != nil {
 		var existsErr *cloudformation.ErrStackAlreadyExists
 		if errors.As(err, &existsErr) {
 			// Do nothing if the stack already exists.
@@ -768,6 +787,28 @@ func (o *initEnvOpts) validateCredentials() error {
 	return nil
 }
 
+func (o *initEnvOpts) validateInternalALBSubnets() error {
+	if len(o.internalALBSubnets) == 0 {
+		return nil
+	}
+	isImported := make(map[string]bool)
+	for _, placementSubnet := range o.internalALBSubnets {
+		for _, subnet := range append(o.importVPC.PrivateSubnetIDs, o.importVPC.PublicSubnetIDs...) {
+			if placementSubnet == subnet {
+				isImported[placementSubnet] = true
+			}
+		}
+	}
+	if len(isImported) != len(o.internalALBSubnets) {
+		return fmt.Errorf("%s '%s' %s designated for ALB placement, but %s imported",
+			english.PluralWord(len(o.internalALBSubnets), "subnet", "subnets"),
+			strings.Join(o.internalALBSubnets, ", "),
+			english.PluralWord(len(o.internalALBSubnets), "was", "were"),
+			english.PluralWord(len(o.internalALBSubnets), "it was not", "they were not all"))
+	}
+	return nil
+}
+
 // cleanUpDanglingRoles deletes any IAM roles created for the same app and env that were left over from a previous
 // environment creation.
 func (o *initEnvOpts) cleanUpDanglingRoles(app, env string) error {
@@ -859,6 +900,8 @@ func buildEnvInitCmd() *cobra.Command {
 	// TODO: use IPNetSliceVar when it is available (https://github.com/spf13/pflag/issues/273).
 	cmd.Flags().StringSliceVar(&vars.adjustVPC.PublicSubnetCIDRs, overridePublicSubnetCIDRsFlag, nil, overridePublicSubnetCIDRsFlagDescription)
 	cmd.Flags().StringSliceVar(&vars.adjustVPC.PrivateSubnetCIDRs, overridePrivateSubnetCIDRsFlag, nil, overridePrivateSubnetCIDRsFlagDescription)
+	cmd.Flags().StringSliceVar(&vars.internalALBSubnets, internalALBSubnetsFlag, nil, internalALBSubnetsFlagDescription)
+	cmd.Flags().BoolVar(&vars.allowVPCIngress, allowVPCIngressFlag, false, allowVPCIngressFlagDescription)
 	cmd.Flags().BoolVar(&vars.defaultConfig, defaultConfigFlag, false, defaultConfigFlagDescription)
 
 	flags := pflag.NewFlagSet("Common", pflag.ContinueOnError)
@@ -876,11 +919,14 @@ func buildEnvInitCmd() *cobra.Command {
 	resourcesImportFlags.AddFlag(cmd.Flags().Lookup(publicSubnetsFlag))
 	resourcesImportFlags.AddFlag(cmd.Flags().Lookup(privateSubnetsFlag))
 	resourcesImportFlags.AddFlag(cmd.Flags().Lookup(certsFlag))
+
 	resourcesConfigFlags := pflag.NewFlagSet("Configure Default Resources", pflag.ContinueOnError)
 	resourcesConfigFlags.AddFlag(cmd.Flags().Lookup(overrideVPCCIDRFlag))
 	resourcesConfigFlags.AddFlag(cmd.Flags().Lookup(overrideAZsFlag))
 	resourcesConfigFlags.AddFlag(cmd.Flags().Lookup(overridePublicSubnetCIDRsFlag))
 	resourcesConfigFlags.AddFlag(cmd.Flags().Lookup(overridePrivateSubnetCIDRsFlag))
+	resourcesConfigFlags.AddFlag(cmd.Flags().Lookup(internalALBSubnetsFlag))
+	resourcesConfigFlags.AddFlag(cmd.Flags().Lookup(allowVPCIngressFlag))
 
 	telemetryFlags := pflag.NewFlagSet("Telemetry", pflag.ContinueOnError)
 	telemetryFlags.AddFlag(cmd.Flags().Lookup(enableContainerInsightsFlag))
