@@ -28,80 +28,32 @@ type showEnvMocks struct {
 
 func TestEnvShow_Validate(t *testing.T) {
 	testCases := map[string]struct {
-		inputApp         string
-		inputEnvironment string
-		setupMocks       func(mocks showEnvMocks)
+		inVars showEnvVars
 
 		wantedError error
 	}{
-		"skip validation is app flag is not set": {
-			inputEnvironment: "my-env",
-
-			setupMocks: func(m showEnvMocks) {},
-		},
-		"valid app name and environment name": {
-			inputApp:         "my-app",
-			inputEnvironment: "my-env",
-
-			setupMocks: func(m showEnvMocks) {
-				gomock.InOrder(
-					m.storeSvc.EXPECT().GetApplication("my-app").Return(&config.Application{
-						Name: "my-app",
-					}, nil),
-					m.storeSvc.EXPECT().GetEnvironment("my-app", "my-env").Return(&config.Environment{
-						Name: "my-env",
-					}, nil),
-				)
+		"should error when --manifest and --json are used together": {
+			inVars: showEnvVars{
+				shouldOutputManifest: true,
+				shouldOutputJSON:     true,
 			},
-
-			wantedError: nil,
+			wantedError: errors.New("--manifest and --json cannot be specified together"),
 		},
-		"invalid app name": {
-			inputApp:         "my-app",
-			inputEnvironment: "my-env",
-
-			setupMocks: func(m showEnvMocks) {
-				m.storeSvc.EXPECT().GetApplication("my-app").Return(nil, errors.New("some error"))
+		"should error when --manifest and --resources are used together": {
+			inVars: showEnvVars{
+				shouldOutputManifest:  true,
+				shouldOutputResources: true,
 			},
-
-			wantedError: fmt.Errorf("some error"),
-		},
-		"invalid environment name": {
-			inputApp:         "my-app",
-			inputEnvironment: "my-env",
-
-			setupMocks: func(m showEnvMocks) {
-				gomock.InOrder(
-					m.storeSvc.EXPECT().GetApplication("my-app").Return(&config.Application{
-						Name: "my-app",
-					}, nil),
-					m.storeSvc.EXPECT().GetEnvironment("my-app", "my-env").Return(nil, errors.New("some error")),
-				)
-			},
-
-			wantedError: fmt.Errorf("some error"),
+			wantedError: errors.New("--manifest and --resources cannot be specified together"),
 		},
+		"should not error by default": {},
 	}
 
 	for name, tc := range testCases {
 		t.Run(name, func(t *testing.T) {
-			ctrl := gomock.NewController(t)
-			defer ctrl.Finish()
-
-			mockStoreReader := mocks.NewMockstore(ctrl)
-
-			mocks := showEnvMocks{
-				storeSvc: mockStoreReader,
-			}
-
-			tc.setupMocks(mocks)
 
 			showEnvs := &showEnvOpts{
-				showEnvVars: showEnvVars{
-					name:    tc.inputEnvironment,
-					appName: tc.inputApp,
-				},
-				store: mockStoreReader,
+				showEnvVars: tc.inVars,
 			}
 
 			// WHEN
@@ -129,15 +81,36 @@ func TestEnvShow_Ask(t *testing.T) {
 		wantedEnv   string
 		wantedError error
 	}{
-		"with all flags": {
+		"ensure resources are registered in SSM if users passes flags": {
 			inputApp: "my-app",
 			inputEnv: "my-env",
 
-			setupMocks: func(mocks showEnvMocks) {},
+			setupMocks: func(m showEnvMocks) {
+				m.storeSvc.EXPECT().GetApplication("my-app").Return(nil, nil)
+				m.storeSvc.EXPECT().GetEnvironment("my-app", "my-env").Return(nil, nil)
+			},
 
 			wantedApp: "my-app",
 			wantedEnv: "my-env",
 		},
+		"should wrap error if validation of app name fails": {
+			inputApp: "my-app",
+
+			setupMocks: func(m showEnvMocks) {
+				m.storeSvc.EXPECT().GetApplication("my-app").Return(nil, mockErr)
+			},
+			wantedError: errors.New(`validate application name "my-app": some error`),
+		},
+		"should wrap error if validation of env name fails": {
+			inputApp: "my-app",
+			inputEnv: "my-env",
+
+			setupMocks: func(m showEnvMocks) {
+				m.storeSvc.EXPECT().GetApplication("my-app").Return(nil, nil)
+				m.storeSvc.EXPECT().GetEnvironment("my-app", "my-env").Return(nil, mockErr)
+			},
+			wantedError: errors.New(`validate environment name "my-env" in application "my-app": some error`),
+		},
 		"returns error when fail to select app": {
 			inputApp: "",
 			inputEnv: "",
@@ -153,6 +126,7 @@ func TestEnvShow_Ask(t *testing.T) {
 			inputEnv: "",
 
 			setupMocks: func(m showEnvMocks) {
+				m.storeSvc.EXPECT().GetApplication("my-app").Return(nil, nil)
 				m.sel.EXPECT().Environment(fmt.Sprintf(envShowNamePrompt, color.HighlightUserInput("my-app")), envShowHelpPrompt, "my-app").Return("", mockErr)
 			},
 
@@ -180,9 +154,11 @@ func TestEnvShow_Ask(t *testing.T) {
 			defer ctrl.Finish()
 
 			mockSelector := mocks.NewMockconfigSelector(ctrl)
+			mockStore := mocks.NewMockstore(ctrl)
 
 			mocks := showEnvMocks{
-				sel: mockSelector,
+				sel:      mockSelector,
+				storeSvc: mockStore,
 			}
 
 			tc.setupMocks(mocks)
@@ -192,7 +168,8 @@ func TestEnvShow_Ask(t *testing.T) {
 					name:    tc.inputEnv,
 					appName: tc.inputApp,
 				},
-				sel: mockSelector,
+				sel:   mockSelector,
+				store: mockStore,
 			}
 			// WHEN
 			err := showEnvs.Ask()
@@ -210,63 +187,57 @@ func TestEnvShow_Ask(t *testing.T) {
 
 func TestEnvShow_Execute(t *testing.T) {
 	mockError := errors.New("some error")
-	testEnv := &config.Environment{
-		App:              "testApp",
-		Name:             "testEnv",
-		Region:           "us-west-2",
-		AccountID:        "123456789012",
-		Prod:             false,
-		RegistryURL:      "",
-		ExecutionRoleARN: "",
-		ManagerRoleARN:   "",
-	}
-	testSvc1 := &config.Workload{
-		App:  "testApp",
-		Name: "testSvc1",
-		Type: "load-balanced",
-	}
-	testSvc2 := &config.Workload{
-		App:  "testApp",
-		Name: "testSvc2",
-		Type: "load-balanced",
-	}
-	testSvc3 := &config.Workload{
-		App:  "testApp",
-		Name: "testSvc3",
-		Type: "load-balanced",
-	}
-	testJob1 := &config.Workload{
-		App:  "testApp",
-		Name: "testJob1",
-		Type: "Scheduled Job",
-	}
-	testJob2 := &config.Workload{
-		App:  "testApp",
-		Name: "testJob2",
-		Type: "Scheduled Job",
-	}
-	var wantedResources = []*stack.Resource{
-		{
-			Type:       "AWS::IAM::Role",
-			PhysicalID: "testApp-testEnv-CFNExecutionRole",
-		},
-		{
-			Type:       "testApp-testEnv-Cluster",
-			PhysicalID: "AWS::ECS::Cluster-jI63pYBWU6BZ",
-		},
-	}
-	mockTags := map[string]string{"copilot-application": "testApp", "copilot-environment": "testEnv", "key1": "value1", "key2": "value2"}
 	mockEnvDescription := describe.EnvDescription{
-		Environment: testEnv,
-		Services:    []*config.Workload{testSvc1, testSvc2, testSvc3},
-		Jobs:        []*config.Workload{testJob1, testJob2},
-		Tags:        mockTags,
-		Resources:   wantedResources,
+		Environment: &config.Environment{
+			App:              "testApp",
+			Name:             "testEnv",
+			Region:           "us-west-2",
+			AccountID:        "123456789012",
+			Prod:             false,
+			RegistryURL:      "",
+			ExecutionRoleARN: "",
+			ManagerRoleARN:   "",
+		},
+		Services: []*config.Workload{
+			{
+				App:  "testApp",
+				Name: "testSvc1",
+				Type: "load-balanced",
+			}, {
+				App:  "testApp",
+				Name: "testSvc2",
+				Type: "load-balanced",
+			}, {
+				App:  "testApp",
+				Name: "testSvc3",
+				Type: "load-balanced",
+			}},
+		Jobs: []*config.Workload{{
+			App:  "testApp",
+			Name: "testJob1",
+			Type: "Scheduled Job",
+		}, {
+			App:  "testApp",
+			Name: "testJob2",
+			Type: "Scheduled Job",
+		}},
+		Tags: map[string]string{"copilot-application": "testApp", "copilot-environment": "testEnv", "key1": "value1", "key2": "value2"},
+		Resources: []*stack.Resource{
+			{
+				Type:       "AWS::IAM::Role",
+				PhysicalID: "testApp-testEnv-CFNExecutionRole",
+			},
+			{
+				Type:       "testApp-testEnv-Cluster",
+				PhysicalID: "AWS::ECS::Cluster-jI63pYBWU6BZ",
+			},
+		},
 	}
 
 	testCases := map[string]struct {
-		inputEnv         string
-		shouldOutputJSON bool
+		inputEnv             string
+		shouldOutputJSON     bool
+		shouldOutputManifest bool
 
 		setupMocks func(mocks showEnvMocks)
 
@@ -276,9 +247,7 @@ func TestEnvShow_Execute(t *testing.T) {
 		"return error if fail to describe the env": {
 			inputEnv: "testEnv",
 			setupMocks: func(m showEnvMocks) {
-				gomock.InOrder(
-					m.describer.EXPECT().Describe().Return(nil, mockError),
-				)
+				m.describer.EXPECT().Describe().Return(nil, mockError)
 			},
 
 			wantedError: fmt.Errorf("describe environment testEnv: some error"),
@@ -287,19 +256,15 @@ func TestEnvShow_Execute(t *testing.T) {
 			inputEnv:         "testEnv",
 			shouldOutputJSON: true,
 			setupMocks: func(m showEnvMocks) {
-				gomock.InOrder(
-					m.describer.EXPECT().Describe().Return(&mockEnvDescription, mockError),
-				)
+				m.describer.EXPECT().Describe().Return(&mockEnvDescription, mockError)
 			},
 
 			wantedError: fmt.Errorf("describe environment testEnv: some error"),
 		},
-		"success in human format": {
+		"should print human format": {
 			inputEnv: "testEnv",
 			setupMocks: func(m showEnvMocks) {
-				gomock.InOrder(
-					m.describer.EXPECT().Describe().Return(&mockEnvDescription, nil),
-				)
+				m.describer.EXPECT().Describe().Return(&mockEnvDescription, nil)
 			},
 
 			wantedContent: `About
@@ -334,17 +299,24 @@ Resources
   testApp-testEnv-Cluster  AWS::ECS::Cluster-jI63pYBWU6BZ
 `,
 		},
-		"success in JSON format": {
+		"should print JSON format": {
 			inputEnv:         "testEnv",
 			shouldOutputJSON: true,
 			setupMocks: func(m showEnvMocks) {
-				gomock.InOrder(
-					m.describer.EXPECT().Describe().Return(&mockEnvDescription, nil),
-				)
+				m.describer.EXPECT().Describe().Return(&mockEnvDescription, nil)
 			},
 
 			wantedContent: "{\"environment\":{\"app\":\"testApp\",\"name\":\"testEnv\",\"region\":\"us-west-2\",\"accountID\":\"123456789012\",\"prod\":false,\"registryURL\":\"\",\"executionRoleARN\":\"\",\"managerRoleARN\":\"\"},\"services\":[{\"app\":\"testApp\",\"name\":\"testSvc1\",\"type\":\"load-balanced\"},{\"app\":\"testApp\",\"name\":\"testSvc2\",\"type\":\"load-balanced\"},{\"app\":\"testApp\",\"name\":\"testSvc3\",\"type\":\"load-balanced\"}],\"jobs\":[{\"app\":\"testApp\",\"name\":\"testJob1\",\"type\":\"Scheduled Job\"},{\"app\":\"testApp\",\"name\":\"testJob2\",\"type\":\"Scheduled Job\"}],\"tags\":{\"copilot-application\":\"testApp\",\"copilot-environment\":\"testEnv\",\"key1\":\"value1\",\"key2\":\"value2\"},\"resources\":[{\"type\":\"AWS::IAM::Role\",\"physicalID\":\"testApp-testEnv-CFNExecutionRole\"},{\"type\":\"testApp-testEnv-Cluster\",\"physicalID\":\"AWS::ECS::Cluster-jI63pYBWU6BZ\"}],\"environmentVPC\":{\"id\":\"\",\"publicSubnetIDs\":null,\"privateSubnetIDs\":null}}\n",
 		},
+		"should print manifest file": {
+			inputEnv:             "testEnv",
+			shouldOutputManifest: true,
+			setupMocks: func(m showEnvMocks) {
+				m.describer.EXPECT().Manifest().Return([]byte("hello"), nil)
+			},
+
+			wantedContent: "hello\n",
+		},
 	}
 
 	for name, tc := range testCases {
@@ -364,8 +336,9 @@ Resources
 
 			showEnvs := &showEnvOpts{
 				showEnvVars: showEnvVars{
-					name:             tc.inputEnv,
-					shouldOutputJSON: tc.shouldOutputJSON,
+					name:                 tc.inputEnv,
+					shouldOutputJSON:     tc.shouldOutputJSON,
+					shouldOutputManifest: tc.shouldOutputManifest,
 				},
 				store:            mockStoreReader,
 				describer:        mockEnvDescriber,
