@@ -283,6 +283,10 @@ type wsWlDirReader interface {
 	Summary() (*workspace.Summary, error)
 }
 
+type wsEnvironmentReader interface {
+	ReadEnvironmentManifest(mftDirName string) (workspace.EnvironmentManifest, error)
+}
+
 type wsPipelineReader interface {
 	wsPipelineGetter
 	Rel(path string) (string, error)
@@ -322,7 +326,7 @@ type bucketEmptier interface {
 
 // Interfaces for deploying resources through CloudFormation. Facilitates mocking.
 type environmentDeployer interface {
-	DeployAndRenderEnvironment(out termprogress.FileWriter, env *deploy.CreateEnvironmentInput) error
+	CreateAndRenderEnvironment(out termprogress.FileWriter, env *deploy.CreateEnvironmentInput) error
 	DeleteEnvironment(appName, envName, cfnExecRoleARN string) error
 	GetEnvironment(appName, envName string) (*config.Environment, error)
 	EnvironmentTemplate(appName, envName string) (string, error)
@@ -413,6 +417,12 @@ type statusDescriber interface {
 type envDescriber interface {
 	Describe() (*describe.EnvDescription, error)
 	PublicCIDRBlocks() ([]string, error)
+	Manifest() ([]byte, error)
+}
+
+type versionCompatibilityChecker interface {
+	versionGetter
+	AvailableFeatures() ([]string, error)
 }
 
 type versionGetter interface {
@@ -486,6 +496,10 @@ type wsPipelineSelector interface {
 	WsPipeline(prompt, help string) (*workspace.PipelineManifest, error)
 }
 
+type wsEnvironmentSelector interface {
+	LocalEnvironment(msg, help string) (wl string, err error)
+}
+
 type codePipelineSelector interface {
 	appSelector
 	DeployedPipeline(prompt, help, app string) (deploy.Pipeline, error)
@@ -630,3 +644,8 @@ type workloadTemplateGenerator interface {
 	GenerateCloudFormationTemplate(in *clideploy.GenerateCloudFormationTemplateInput) (
 		*clideploy.GenerateCloudFormationTemplateOutput, error)
 }
+
+type envDeployer interface {
+	DeployEnvironment(in *clideploy.DeployEnvironmentInput) error
+	UploadArtifacts() (map[string]string, error)
+}
