@@ -9,10 +9,11 @@ import (
 	"fmt"
 	"testing"
 
-	"github.com/aws/copilot-cli/internal/pkg/cli/mocks"
-	"github.com/aws/copilot-cli/internal/pkg/config"
 	"github.com/golang/mock/gomock"
 	"github.com/stretchr/testify/require"
+
+	"github.com/aws/copilot-cli/internal/pkg/cli/mocks"
+	"github.com/aws/copilot-cli/internal/pkg/config"
 )
 
 type showSvcMocks struct {
@@ -36,94 +37,7 @@ func (m *mockDescribeData) JSONString() (string, error) {
 }
 
 func TestSvcShow_Validate(t *testing.T) {
-	testCases := map[string]struct {
-		inputApp   string
-		inputSvc   string
-		setupMocks func(mocks showSvcMocks)
-
-		wantedError error
-	}{
-		"skip validation if app flag is not set": {
-			inputSvc: "my-svc",
-
-			setupMocks: func(m showSvcMocks) {},
-		},
-		"valid app name and service name": {
-			inputApp: "my-app",
-			inputSvc: "my-svc",
-
-			setupMocks: func(m showSvcMocks) {
-				gomock.InOrder(
-					m.storeSvc.EXPECT().GetApplication("my-app").Return(&config.Application{
-						Name: "my-app",
-					}, nil),
-					m.storeSvc.EXPECT().GetService("my-app", "my-svc").Return(&config.Workload{
-						Name: "my-svc",
-					}, nil),
-				)
-			},
-
-			wantedError: nil,
-		},
-		"fail to get app": {
-			inputApp: "my-app",
-			inputSvc: "my-svc",
-
-			setupMocks: func(m showSvcMocks) {
-				m.storeSvc.EXPECT().GetApplication("my-app").Return(nil, errors.New("some error"))
-			},
-
-			wantedError: fmt.Errorf("some error"),
-		},
-		"fail to get service": {
-			inputApp: "my-app",
-			inputSvc: "my-svc",
-
-			setupMocks: func(m showSvcMocks) {
-				gomock.InOrder(
-					m.storeSvc.EXPECT().GetApplication("my-app").Return(&config.Application{
-						Name: "my-app",
-					}, nil),
-					m.storeSvc.EXPECT().GetService("my-app", "my-svc").Return(nil, errors.New("some error")),
-				)
-			},
-
-			wantedError: fmt.Errorf("some error"),
-		},
-	}
-
-	for name, tc := range testCases {
-		t.Run(name, func(t *testing.T) {
-			ctrl := gomock.NewController(t)
-			defer ctrl.Finish()
-
-			mockStoreReader := mocks.NewMockstore(ctrl)
-
-			mocks := showSvcMocks{
-				storeSvc: mockStoreReader,
-			}
-
-			tc.setupMocks(mocks)
-
-			showSvcs := &showSvcOpts{
-				showSvcVars: showSvcVars{
-					svcName: tc.inputSvc,
-					appName: tc.inputApp,
-				},
-				store: mockStoreReader,
-			}
-
-			// WHEN
-			err := showSvcs.Validate()
-
-			// THEN
-			if tc.wantedError != nil {
-				require.EqualError(t, err, tc.wantedError.Error())
-			} else {
-				require.NoError(t, err)
-			}
-		})
-	}
+	// NOTE: no optional flag needs to be validated for this command.
 }
 
 func TestSvcShow_Ask(t *testing.T) {
@@ -137,51 +51,51 @@ func TestSvcShow_Ask(t *testing.T) {
 		wantedSvc   string
 		wantedError error
 	}{
-		"with all flags": {
-			inputApp:   "my-app",
-			inputSvc:   "my-svc",
-			setupMocks: func(mocks showSvcMocks) {},
-
-			wantedApp:   "my-app",
-			wantedSvc:   "my-svc",
-			wantedError: nil,
-		},
-		"success": {
-			inputApp: "",
-			inputSvc: "",
-
+		"validate instead of prompting application name and svc name": {
+			inputApp: "my-app",
+			inputSvc: "my-svc",
 			setupMocks: func(m showSvcMocks) {
-				gomock.InOrder(
-					m.sel.EXPECT().Application(svcAppNamePrompt, svcAppNameHelpPrompt).Return("my-app", nil),
-					m.sel.EXPECT().Service(fmt.Sprintf(svcShowSvcNamePrompt, "my-app"), svcShowSvcNameHelpPrompt, "my-app").Return("my-svc", nil),
-				)
+				m.storeSvc.EXPECT().GetApplication("my-app").Return(&config.Application{}, nil)
+				m.storeSvc.EXPECT().GetService("my-app", "my-svc").Return(&config.Workload{}, nil)
 			},
-
-			wantedApp:   "my-app",
-			wantedSvc:   "my-svc",
-			wantedError: nil,
+			wantedApp: "my-app",
+			wantedSvc: "my-svc",
 		},
-		"returns error when fail to select apps": {
-			inputApp: "",
-			inputSvc: "",
-
+		"prompt for app name": {
+			inputSvc: "my-svc",
+			setupMocks: func(m showSvcMocks) {
+				m.sel.EXPECT().Application(gomock.Any(), gomock.Any(), gomock.Any()).Return("my-app", nil)
+				m.storeSvc.EXPECT().GetApplication("my-app").Times(0)
+				m.storeSvc.EXPECT().GetService("my-app", "my-svc").AnyTimes()
+			},
+			wantedApp: "my-app",
+			wantedSvc: "my-svc",
+		},
+		"error when fail to select apps": {
+			inputSvc: "my-svc",
 			setupMocks: func(m showSvcMocks) {
 				m.sel.EXPECT().Application(svcAppNamePrompt, svcAppNameHelpPrompt).Return("", errors.New("some error"))
 			},
-
 			wantedError: fmt.Errorf("select application name: some error"),
 		},
-		"returns error when fail to select services": {
-			inputApp: "",
-			inputSvc: "",
-
+		"prompt for service name": {
+			inputApp: "my-app",
+			setupMocks: func(m showSvcMocks) {
+				m.sel.EXPECT().Service(fmt.Sprintf(svcShowSvcNamePrompt, "my-app"), svcShowSvcNameHelpPrompt, "my-app").Return("my-svc", nil)
+				m.storeSvc.EXPECT().GetService("my-app", "my-svc").Times(0)
+				m.storeSvc.EXPECT().GetApplication("my-app").AnyTimes()
+				m.sel.EXPECT().Application(svcAppNamePrompt, svcAppNameHelpPrompt).AnyTimes()
+			},
+			wantedApp: "my-app",
+			wantedSvc: "my-svc",
+		},
+		"error when fail to select services": {
 			setupMocks: func(m showSvcMocks) {
 				gomock.InOrder(
 					m.sel.EXPECT().Application(svcAppNamePrompt, svcAppNameHelpPrompt).Return("my-app", nil),
 					m.sel.EXPECT().Service(fmt.Sprintf(svcShowSvcNamePrompt, "my-app"), svcShowSvcNameHelpPrompt, "my-app").Return("", errors.New("some error")),
 				)
 			},
-
 			wantedError: fmt.Errorf("select service for application my-app: some error"),
 		},
 	}
