@@ -24,13 +24,13 @@ type execTaskMocks struct {
 	taskSel          *mocks.MockrunningTaskSelector
 	commandExec      *mocks.MockecsCommandExecutor
 	ssmPluginManager *mocks.MockssmPluginManager
+	provider         *mocks.MocksessionProvider
 }
 
 func TestTaskExec_Validate(t *testing.T) {
 	const (
-		mockApp       = "my-app"
-		mockEnv       = "my-env"
-		mockTaskGroup = "my-task-group"
+		mockApp = "my-app"
+		mockEnv = "my-env"
 	)
 	mockErr := errors.New("some error")
 	testCases := map[string]struct {
@@ -133,10 +133,8 @@ func TestTaskExec_Validate(t *testing.T) {
 
 func TestTaskExec_Ask(t *testing.T) {
 	const (
-		mockApp       = "my-app"
-		mockEnv       = "my-env"
-		mockTaskGroup = "my-task-group"
-		mockTaskID    = "my-task-id"
+		mockApp = "my-app"
+		mockEnv = "my-env"
 	)
 	mockTask := &ecs.Task{
 		TaskArn: aws.String("mockTaskARN"),
@@ -157,6 +155,7 @@ func TestTaskExec_Ask(t *testing.T) {
 		"should bubble error if fail to select task in default cluster": {
 			useDefault: true,
 			setupMocks: func(m execTaskMocks) {
+				m.provider.EXPECT().Default().Return(&session.Session{}, nil)
 				m.taskSel.EXPECT().RunningTask(taskExecTaskPrompt, taskExecTaskHelpPrompt,
 					gomock.Any(), gomock.Any(), gomock.Any()).Return(nil, mockErr)
 			},
@@ -194,6 +193,7 @@ func TestTaskExec_Ask(t *testing.T) {
 			inEnv: mockEnv,
 			setupMocks: func(m execTaskMocks) {
 				m.storeSvc.EXPECT().GetEnvironment(mockApp, mockEnv).Return(&config.Environment{}, nil)
+				m.provider.EXPECT().FromRole(gomock.Any(), gomock.Any())
 				m.taskSel.EXPECT().RunningTask(taskExecTaskPrompt, taskExecTaskHelpPrompt,
 					gomock.Any(), gomock.Any(), gomock.Any()).Return(nil, mockErr)
 			},
@@ -203,6 +203,7 @@ func TestTaskExec_Ask(t *testing.T) {
 		"success with default flag set": {
 			useDefault: true,
 			setupMocks: func(m execTaskMocks) {
+				m.provider.EXPECT().Default().Return(&session.Session{}, nil)
 				m.taskSel.EXPECT().RunningTask(taskExecTaskPrompt, taskExecTaskHelpPrompt,
 					gomock.Any(), gomock.Any(), gomock.Any()).Return(mockTask, nil)
 			},
@@ -210,8 +211,9 @@ func TestTaskExec_Ask(t *testing.T) {
 			wantedTask:       mockTask,
 			wantedUseDefault: true,
 		},
-		"success with default option choosed": {
+		"success with default option chose": {
 			setupMocks: func(m execTaskMocks) {
+				m.provider.EXPECT().Default().Return(&session.Session{}, nil)
 				m.configSel.EXPECT().Application(taskExecAppNamePrompt, taskExecAppNameHelpPrompt, useDefaultClusterOption).
 					Return(useDefaultClusterOption, nil)
 				m.taskSel.EXPECT().RunningTask(taskExecTaskPrompt, taskExecTaskHelpPrompt,
@@ -228,6 +230,7 @@ func TestTaskExec_Ask(t *testing.T) {
 				m.configSel.EXPECT().Environment(taskExecEnvNamePrompt, taskExecEnvNameHelpPrompt, mockApp, useDefaultClusterOption).
 					Return(mockEnv, nil)
 				m.storeSvc.EXPECT().GetEnvironment(mockApp, mockEnv).Return(&config.Environment{}, nil)
+				m.provider.EXPECT().FromRole(gomock.Any(), gomock.Any())
 				m.taskSel.EXPECT().RunningTask(taskExecTaskPrompt, taskExecTaskHelpPrompt,
 					gomock.Any(), gomock.Any(), gomock.Any()).Return(mockTask, nil)
 			},
@@ -248,10 +251,12 @@ func TestTaskExec_Ask(t *testing.T) {
 			mockNewTaskSel := func(_ *session.Session) runningTaskSelector {
 				return mockTaskSel
 			}
+			mockProvider := mocks.NewMocksessionProvider(ctrl)
 			mocks := execTaskMocks{
 				storeSvc:  mockStoreReader,
 				configSel: mockConfigSel,
 				taskSel:   mockTaskSel,
+				provider:  mockProvider,
 			}
 
 			tc.setupMocks(mocks)
@@ -269,6 +274,7 @@ func TestTaskExec_Ask(t *testing.T) {
 				store:      mockStoreReader,
 				newTaskSel: mockNewTaskSel,
 				configSel:  mockConfigSel,
+				provider:   mockProvider,
 			}
 
 			// WHEN
@@ -332,7 +338,9 @@ func TestTaskExec_Execute(t *testing.T) {
 					},
 				},
 			},
-			setupMocks: func(m execTaskMocks) {},
+			setupMocks: func(m execTaskMocks) {
+				m.provider.EXPECT().Default()
+			},
 
 			wantedError: fmt.Errorf("parse task ARN mockBadTaskARN: parse ECS task ARN: arn: invalid prefix"),
 		},
@@ -340,6 +348,7 @@ func TestTaskExec_Execute(t *testing.T) {
 			inTask:       mockTask,
 			inUseDefault: true,
 			setupMocks: func(m execTaskMocks) {
+				m.provider.EXPECT().Default()
 				m.commandExec.EXPECT().ExecuteCommand(ecs.ExecuteCommandInput{
 					Cluster:   mockClusterARN,
 					Command:   mockCommand,
@@ -354,6 +363,7 @@ func TestTaskExec_Execute(t *testing.T) {
 			inTask: mockTask,
 			setupMocks: func(m execTaskMocks) {
 				m.storeSvc.EXPECT().GetEnvironment(mockApp, mockEnv).Return(&config.Environment{}, nil)
+				m.provider.EXPECT().FromRole(gomock.Any(), gomock.Any())
 				m.commandExec.EXPECT().ExecuteCommand(ecs.ExecuteCommandInput{
 					Cluster:   mockClusterARN,
 					Command:   mockCommand,
@@ -377,6 +387,7 @@ func TestTaskExec_Execute(t *testing.T) {
 			mocks := execTaskMocks{
 				storeSvc:    mockStoreReader,
 				commandExec: mockCommandExec,
+				provider:    mocks.NewMocksessionProvider(ctrl),
 			}
 
 			tc.setupMocks(mocks)
@@ -393,6 +404,7 @@ func TestTaskExec_Execute(t *testing.T) {
 				task:               tc.inTask,
 				store:              mockStoreReader,
 				newCommandExecutor: mockNewCommandExec,
+				provider:           mocks.provider,
 			}
 
 			// WHEN
