@@ -11,6 +11,11 @@ import (
 	"testing"
 	"time"
 
+	"github.com/aws/aws-sdk-go/aws"
+	"github.com/aws/aws-sdk-go/service/ssm"
+	"github.com/aws/copilot-cli/internal/pkg/aws/identity"
+	"github.com/aws/copilot-cli/internal/pkg/aws/sessions"
+
 	"github.com/aws/copilot-cli/internal/pkg/config"
 	"github.com/stretchr/testify/require"
 )
@@ -20,68 +25,74 @@ func init() {
 }
 
 func Test_SSM_Application_Integration(t *testing.T) {
-	s, _ := config.NewStore()
+	defaultSess, err := sessions.ImmutableProvider().Default()
+	require.NoError(t, err)
+
+	store := config.NewSSMStore(identity.New(defaultSess), ssm.New(defaultSess), aws.StringValue(defaultSess.Config.Region))
 	applicationToCreate := config.Application{Name: randStringBytes(10), Version: "1.0"}
-	defer s.DeleteApplication(applicationToCreate.Name)
+	defer store.DeleteApplication(applicationToCreate.Name)
 
 	t.Run("Create, Get and List Applications", func(t *testing.T) {
 		// Create our first application
-		err := s.CreateApplication(&applicationToCreate)
+		err := store.CreateApplication(&applicationToCreate)
 		require.NoError(t, err)
 
 		// Can't overwrite an existing application
-		err = s.CreateApplication(&applicationToCreate)
+		err = store.CreateApplication(&applicationToCreate)
 		require.NoError(t, err)
 
 		// Fetch the application back from SSM
-		application, err := s.GetApplication(applicationToCreate.Name)
+		application, err := store.GetApplication(applicationToCreate.Name)
 		require.NoError(t, err)
 		require.Equal(t, applicationToCreate, *application)
 
 		// List returns a non-empty list of applications
-		applications, err := s.ListApplications()
+		applications, err := store.ListApplications()
 		require.NoError(t, err)
 		require.NotEmpty(t, applications)
 	})
 }
 
 func Test_SSM_Environment_Integration(t *testing.T) {
-	s, _ := config.NewStore()
+	defaultSess, err := sessions.ImmutableProvider().Default()
+	require.NoError(t, err)
+
+	store := config.NewSSMStore(identity.New(defaultSess), ssm.New(defaultSess), aws.StringValue(defaultSess.Config.Region))
 	applicationToCreate := config.Application{Name: randStringBytes(10), Version: "1.0"}
 	testEnvironment := config.Environment{Name: "test", App: applicationToCreate.Name, Region: "us-west-2", AccountID: " 1234", Prod: false}
 	prodEnvironment := config.Environment{Name: "prod", App: applicationToCreate.Name, Region: "us-west-2", AccountID: " 1234", Prod: true}
 
 	defer func() {
-		s.DeleteEnvironment(applicationToCreate.Name, testEnvironment.Name)
-		s.DeleteEnvironment(applicationToCreate.Name, prodEnvironment.Name)
-		s.DeleteApplication(applicationToCreate.Name)
+		store.DeleteEnvironment(applicationToCreate.Name, testEnvironment.Name)
+		store.DeleteEnvironment(applicationToCreate.Name, prodEnvironment.Name)
+		store.DeleteApplication(applicationToCreate.Name)
 	}()
 	t.Run("Create, Get and List Environments", func(t *testing.T) {
 		// Create our first application
-		err := s.CreateApplication(&applicationToCreate)
+		err := store.CreateApplication(&applicationToCreate)
 		require.NoError(t, err)
 
 		// Make sure there are no envs with our new application
-		envs, err := s.ListEnvironments(applicationToCreate.Name)
+		envs, err := store.ListEnvironments(applicationToCreate.Name)
 		require.NoError(t, err)
 		require.Empty(t, envs)
 
 		// Add our environments
-		err = s.CreateEnvironment(&testEnvironment)
+		err = store.CreateEnvironment(&testEnvironment)
 		require.NoError(t, err)
 
-		err = s.CreateEnvironment(&prodEnvironment)
+		err = store.CreateEnvironment(&prodEnvironment)
 		require.NoError(t, err)
 
 		// Skip and do not return error if environment already exists
-		err = s.CreateEnvironment(&prodEnvironment)
+		err = store.CreateEnvironment(&prodEnvironment)
 		require.NoError(t, err)
 
 		// Wait for consistency to kick in (ssm path commands are eventually consistent)
 		time.Sleep(5 * time.Second)
 
 		// Make sure all the environments are under our application
-		envs, err = s.ListEnvironments(applicationToCreate.Name)
+		envs, err = store.ListEnvironments(applicationToCreate.Name)
 		require.NoError(t, err)
 		var environments []config.Environment
 		for _, e := range envs {
@@ -90,54 +101,57 @@ func Test_SSM_Environment_Integration(t *testing.T) {
 		require.ElementsMatch(t, environments, []config.Environment{testEnvironment, prodEnvironment})
 
 		// Fetch our saved environments, one by one
-		env, err := s.GetEnvironment(applicationToCreate.Name, testEnvironment.Name)
+		env, err := store.GetEnvironment(applicationToCreate.Name, testEnvironment.Name)
 		require.NoError(t, err)
 		require.Equal(t, testEnvironment, *env)
 
-		env, err = s.GetEnvironment(applicationToCreate.Name, prodEnvironment.Name)
+		env, err = store.GetEnvironment(applicationToCreate.Name, prodEnvironment.Name)
 		require.NoError(t, err)
 		require.Equal(t, prodEnvironment, *env)
 	})
 }
 
 func Test_SSM_Service_Integration(t *testing.T) {
-	s, _ := config.NewStore()
+	defaultSess, err := sessions.ImmutableProvider().Default()
+	require.NoError(t, err)
+
+	store := config.NewSSMStore(identity.New(defaultSess), ssm.New(defaultSess), aws.StringValue(defaultSess.Config.Region))
 	applicationToCreate := config.Application{Name: randStringBytes(10), Version: "1.0"}
 	apiService := config.Workload{Name: "api", App: applicationToCreate.Name, Type: "LBFargateService"}
 	feService := config.Workload{Name: "front-end", App: applicationToCreate.Name, Type: "LBFargateService"}
 
 	defer func() {
-		s.DeleteService(applicationToCreate.Name, apiService.Name)
-		s.DeleteService(applicationToCreate.Name, feService.Name)
-		s.DeleteApplication(applicationToCreate.Name)
+		store.DeleteService(applicationToCreate.Name, apiService.Name)
+		store.DeleteService(applicationToCreate.Name, feService.Name)
+		store.DeleteApplication(applicationToCreate.Name)
 	}()
 
 	t.Run("Create, Get and List Applications", func(t *testing.T) {
 		// Create our first application
-		err := s.CreateApplication(&applicationToCreate)
+		err := store.CreateApplication(&applicationToCreate)
 		require.NoError(t, err)
 
 		// Make sure there are no svcs with our new application
-		svcs, err := s.ListServices(applicationToCreate.Name)
+		svcs, err := store.ListServices(applicationToCreate.Name)
 		require.NoError(t, err)
 		require.Empty(t, svcs)
 
 		// Add our services
-		err = s.CreateService(&apiService)
+		err = store.CreateService(&apiService)
 		require.NoError(t, err)
 
-		err = s.CreateService(&feService)
+		err = store.CreateService(&feService)
 		require.NoError(t, err)
 
 		// Skip and do not return error if services already exists
-		err = s.CreateService(&feService)
+		err = store.CreateService(&feService)
 		require.NoError(t, err)
 
 		// Wait for consistency to kick in (ssm path commands are eventually consistent)
 		time.Sleep(5 * time.Second)
 
 		// Make sure all the svcs are under our application
-		svcs, err = s.ListServices(applicationToCreate.Name)
+		svcs, err = store.ListServices(applicationToCreate.Name)
 		require.NoError(t, err)
 		var services []config.Workload
 		for _, s := range svcs {
@@ -146,11 +160,11 @@ func Test_SSM_Service_Integration(t *testing.T) {
 		require.ElementsMatch(t, services, []config.Workload{apiService, feService})
 
 		// Fetch our saved svcs, one by one
-		svc, err := s.GetService(applicationToCreate.Name, apiService.Name)
+		svc, err := store.GetService(applicationToCreate.Name, apiService.Name)
 		require.NoError(t, err)
 		require.Equal(t, apiService, *svc)
 
-		svc, err = s.GetService(applicationToCreate.Name, feService.Name)
+		svc, err = store.GetService(applicationToCreate.Name, feService.Name)
 		require.NoError(t, err)
 		require.Equal(t, feService, *svc)
 	})
