@@ -58,6 +58,10 @@ func TestCloudFormation_UpgradeEnvironment(t *testing.T) {
 							ParameterKey:     aws.String("ALBWorkloads"),
 							UsePreviousValue: aws.Bool(true),
 						},
+						{
+							ParameterKey:   aws.String("InternalALBWorkloads"),
+							ParameterValue: aws.String(""),
+						},
 						{
 							ParameterKey:   aws.String("AppName"),
 							ParameterValue: aws.String("phonetool"),
@@ -98,6 +102,10 @@ func TestCloudFormation_UpgradeEnvironment(t *testing.T) {
 							ParameterKey:   aws.String("CreateHTTPSListener"),
 							ParameterValue: aws.String("true"),
 						},
+						{
+							ParameterKey:   aws.String("CreateInternalHTTPSListener"),
+							ParameterValue: aws.String("false"),
+						},
 					})
 				})
 				s3 := mocks.NewMocks3Client(ctrl)
@@ -105,7 +113,6 @@ func TestCloudFormation_UpgradeEnvironment(t *testing.T) {
 					require.Contains(t, key, "manual/templates/phonetool-test/")
 					return "url", nil
 				})
-
 				return &CloudFormation{
 					cfnClient: m,
 					s3Client:  s3,
@@ -262,6 +269,10 @@ func TestCloudFormation_UpgradeLegacyEnvironment(t *testing.T) {
 							ParameterKey:   aws.String("ALBWorkloads"),
 							ParameterValue: aws.String("frontend,admin"),
 						},
+						{
+							ParameterKey:   aws.String("InternalALBWorkloads"),
+							ParameterValue: aws.String(""),
+						},
 						{
 							ParameterKey:     aws.String("EnvironmentName"),
 							UsePreviousValue: aws.Bool(true),
@@ -302,6 +313,10 @@ func TestCloudFormation_UpgradeLegacyEnvironment(t *testing.T) {
 							ParameterKey:   aws.String("CreateHTTPSListener"),
 							ParameterValue: aws.String("false"),
 						},
+						{
+							ParameterKey:   aws.String("CreateInternalHTTPSListener"),
+							ParameterValue: aws.String("false"),
+						},
 					})
 				})
 
