@@ -119,7 +119,12 @@ func TestLoadBalancedWebService_Template(t *testing.T) {
 	testLBWebServiceManifest.ImageConfig.HealthCheck = manifest.ContainerHealthCheck{
 		Retries: aws.Int(5),
 	}
-	testLBWebServiceManifest.RoutingRule.Alias = manifest.Alias{String: aws.String("mockAlias")}
+	testLBWebServiceManifest.RoutingRule.Alias = manifest.Alias{AdvancedAliases: []manifest.AdvancedAlias{
+		{
+			Alias:      aws.String("mockAlias"),
+			HostedZone: aws.String("mockHostedZone"),
+		},
+	}}
 	testLBWebServiceManifest.EntryPoint = manifest.EntryPointOverride{
 		String:      nil,
 		StringSlice: []string{"/bin/echo", "hello"},
@@ -130,6 +135,7 @@ func TestLoadBalancedWebService_Template(t *testing.T) {
 	}
 
 	testCases := map[string]struct {
+		noImportedCerts  bool
 		mockDependencies func(t *testing.T, ctrl *gomock.Controller, c *LoadBalancedWebService)
 		wantedTemplate   string
 		wantedError      error
@@ -188,6 +194,21 @@ func TestLoadBalancedWebService_Template(t *testing.T) {
 			},
 			wantedError: fmt.Errorf("parse addons parameters for %s: %w", aws.StringValue(testLBWebServiceManifest.Name), errors.New("some error")),
 		},
+		"failed if hosted zone is set without imported certs": {
+			noImportedCerts: true,
+			mockDependencies: func(t *testing.T, ctrl *gomock.Controller, c *LoadBalancedWebService) {
+				m := mocks.NewMockloadBalancedWebSvcReadParser(ctrl)
+				m.EXPECT().Read(albRulePriorityGeneratorPath).Return(&template.Content{Buffer: bytes.NewBufferString("something")}, nil)
+				m.EXPECT().Read(desiredCountGeneratorPath).Return(&template.Content{Buffer: bytes.NewBufferString("something")}, nil)
+				m.EXPECT().Read(envControllerPath).Return(&template.Content{Buffer: bytes.NewBufferString("something")}, nil)
+				addons := mockAddons{tplErr: &addon.ErrAddonsNotFound{}, paramsErr: &addon.ErrAddonsNotFound{}}
+				c.parser = m
+				c.wkld.addons = addons
+			},
+
+			wantedTemplate: "",
+			wantedError:    fmt.Errorf("cannot specify alias hosted zones when env certificates are managed by Copilot"),
+		},
 		"failed parsing svc template": {
 			mockDependencies: func(t *testing.T, ctrl *gomock.Controller, c *LoadBalancedWebService) {
 				m := mocks.NewMockloadBalancedWebSvcReadParser(ctrl)
@@ -223,6 +244,12 @@ Outputs:
 						HealthCheckPath: "/",
 						GracePeriod:     aws.Int64(60),
 					},
+					UseImportedCerts: true,
+					HostedZoneAliases: template.AliasesForHostedZone{
+						"mockHostedZone": []string{"mockAlias"},
+					},
+					Aliases:             []string{"mockAlias"},
+					HTTPSListener:       true,
 					DeregistrationDelay: aws.Int64(60),
 					HealthCheck:         &overridenContainerHealthCheck,
 					RulePriorityLambda:  "lambda",
@@ -261,6 +288,12 @@ Outputs:
 						SecretOutputs:   []string{"MySecretArn"},
 						PolicyOutputs:   []string{"AdditionalResourcesPolicyArn"},
 					},
+					UseImportedCerts: true,
+					HostedZoneAliases: template.AliasesForHostedZone{
+						"mockHostedZone": []string{"mockAlias"},
+					},
+					Aliases:           []string{"mockAlias"},
+					HTTPSListener:     true,
 					AddonsExtraParams: "ServiceName: !GetAtt Service.Name",
 					WorkloadType:      manifest.LoadBalancedWebServiceType,
 					HTTPHealthCheck: template.HTTPHealthCheckOpts{
@@ -341,7 +374,9 @@ Outputs:
 					},
 					taskDefOverrideFunc: mockCloudFormationOverrideFunc,
 				},
-				manifest: testLBWebServiceManifest,
+				certImported: !tc.noImportedCerts,
+				httpsEnabled: true,
+				manifest:     testLBWebServiceManifest,
 			}
 			tc.mockDependencies(t, ctrl, conf)
 
@@ -717,7 +752,10 @@ func TestLoadBalancedWebService_Parameters(t *testing.T) {
 			setupManifest: func(service *manifest.LoadBalancedWebService) {
 				service.NLBConfig = manifest.NetworkLoadBalancerConfiguration{
 					Aliases: manifest.Alias{
-						StringSlice: []string{"example.com", "v1.example.com"},
+						AdvancedAliases: []manifest.AdvancedAlias{
+							{Alias: aws.String("example.com")},
+							{Alias: aws.String("v1.example.com")},
+						},
 					},
 					Port: aws.String("443/tcp"),
 				}
