@@ -11,6 +11,7 @@ import (
 	"path/filepath"
 	"testing"
 
+	"github.com/aws/copilot-cli/internal/pkg/config"
 	"github.com/aws/copilot-cli/internal/pkg/deploy/cloudformation/stack"
 	"github.com/aws/copilot-cli/internal/pkg/manifest"
 	"github.com/stretchr/testify/require"
@@ -39,12 +40,22 @@ func Test_Stack_Local_Integration(t *testing.T) {
 	v, ok := mft.(*manifest.LoadBalancedWebService)
 	require.Equal(t, ok, true)
 
-	serializer, err := stack.NewLoadBalancedWebService(v, envName, appName, stack.RuntimeConfig{
-		Image: &stack.ECRImage{
-			RepoURL:  imageURL,
-			ImageTag: imageTag,
+	serializer, err := stack.NewLoadBalancedWebService(stack.LoadBalancedWebServiceConfig{
+		App: &config.Application{Name: appName},
+		Env: &config.Environment{
+			Name: envName,
+			CustomConfig: &config.CustomizeEnv{
+				ImportCertARNs: []string{"mockCertARN"},
+			},
 		},
-	}, stack.WithHTTPS())
+		Manifest: v,
+		RuntimeConfig: stack.RuntimeConfig{
+			Image: &stack.ECRImage{
+				RepoURL:  imageURL,
+				ImageTag: imageTag,
+			},
+		},
+	})
 	require.NoError(t, err)
 	tpl, err := serializer.Template()
 	require.NoError(t, err)
