@@ -11,6 +11,7 @@ import (
 	"strings"
 	"text/tabwriter"
 
+	"github.com/aws/copilot-cli/internal/pkg/template"
 	"gopkg.in/yaml.v3"
 
 	"github.com/aws/copilot-cli/internal/pkg/aws/ec2"
@@ -19,6 +20,7 @@ import (
 	"github.com/aws/copilot-cli/internal/pkg/deploy"
 	cfnstack "github.com/aws/copilot-cli/internal/pkg/deploy/cloudformation/stack"
 	"github.com/aws/copilot-cli/internal/pkg/describe/stack"
+	"github.com/aws/copilot-cli/internal/pkg/manifest"
 	"github.com/aws/copilot-cli/internal/pkg/term/color"
 )
 
@@ -131,6 +133,32 @@ func (d *EnvDescriber) Describe() (*EnvDescription, error) {
 	return d.description, nil
 }
 
+// Manifest returns the contents of the manifest used to deploy an environment stack.
+func (d *EnvDescriber) Manifest() ([]byte, error) {
+	tpl, err := d.cfn.StackMetadata()
+	if err != nil {
+		return nil, err
+	}
+
+	metadata := struct {
+		Manifest string `yaml:"Manifest"`
+	}{}
+	if err := yaml.Unmarshal([]byte(tpl), &metadata); err != nil {
+		return nil, fmt.Errorf("unmarshal Metadata.Manifest in environment stack: %v", err)
+	}
+
+	if metadata.Manifest != "" {
+		return []byte(strings.TrimSpace(metadata.Manifest)), nil
+	}
+	// Otherwise, the Manifest wasn't written into the CloudFormation template, we'll convert the config in SSM.
+	mft := manifest.FromEnvConfig(d.env, template.New())
+	out, err := yaml.Marshal(mft)
+	if err != nil {
+		return nil, fmt.Errorf("marshal manifest generated from SSM: %v", err)
+	}
+	return []byte(strings.TrimSpace(string(out))), nil
+}
+
 // Params returns the parameters of the environment stack.
 func (d *EnvDescriber) Params() (map[string]string, error) {
 	descr, err := d.cfn.Describe()
@@ -140,7 +168,7 @@ func (d *EnvDescriber) Params() (map[string]string, error) {
 	return descr.Parameters, nil
 }
 
-// Params returns the outputs of the environment stack.
+// Outputs returns the outputs of the environment stack.
 func (d *EnvDescriber) Outputs() (map[string]string, error) {
 	descr, err := d.cfn.Describe()
 	if err != nil {
@@ -149,6 +177,21 @@ func (d *EnvDescriber) Outputs() (map[string]string, error) {
 	return descr.Outputs, nil
 }
 
+// AvailableFeatures returns the available features of the environment stack.
+func (d *EnvDescriber) AvailableFeatures() ([]string, error) {
+	params, err := d.Params()
+	if err != nil {
+		return nil, err
+	}
+	var availableFeatures []string
+	for _, f := range template.AvailableEnvFeatures() {
+		if _, ok := params[f]; ok {
+			availableFeatures = append(availableFeatures, f)
+		}
+	}
+	return availableFeatures, nil
+}
+
 // Version returns the CloudFormation template version associated with
 // the environment by reading the Metadata.Version field from the template.
 //
