@@ -356,6 +356,7 @@ func TestRequestDrivenWebService_ContainerPlatform(t *testing.T) {
 
 	})
 }
+
 func TestRequestDrivenWebService_Publish(t *testing.T) {
 	testCases := map[string]struct {
 		mft *RequestDrivenWebService
@@ -587,3 +588,39 @@ func TestRequestDrivenWebService_ApplyEnv(t *testing.T) {
 		})
 	}
 }
+
+func TestRequestDrivenWebService_RequiredEnvironmentFeatures(t *testing.T) {
+	testCases := map[string]struct {
+		mft    func(svc *RequestDrivenWebService)
+		wanted []string
+	}{
+		"no feature required by default": {
+			mft: func(svc *RequestDrivenWebService) {},
+		},
+		"nat feature required": {
+			mft: func(svc *RequestDrivenWebService) {
+				svc.Network = RequestDrivenWebServiceNetworkConfig{
+					VPC: rdwsVpcConfig{
+						Placement: PlacementArgOrString{
+							PlacementString: placementStringP(PrivateSubnetPlacement),
+						},
+					},
+				}
+			},
+			wanted: []string{template.NATFeatureName},
+		},
+	}
+	for name, tc := range testCases {
+		t.Run(name, func(t *testing.T) {
+			inSvc := RequestDrivenWebService{
+				Workload: Workload{
+					Name: aws.String("mock-svc"),
+					Type: aws.String(RequestDrivenWebServiceType),
+				},
+			}
+			tc.mft(&inSvc)
+			got := inSvc.RequiredEnvironmentFeatures()
+			require.Equal(t, tc.wanted, got)
+		})
+	}
+}
