@@ -15,7 +15,10 @@ import (
 )
 
 func TestUnmarshalSvc(t *testing.T) {
-	mockPerc := Percentage(70)
+	perc := Percentage(70)
+	mockConfig := ScalingConfigOrPercentage{
+		Value: &perc,
+	}
 	testCases := map[string]struct {
 		inContent string
 
@@ -98,9 +101,12 @@ environments:
 						RoutingRule: RoutingRuleConfigOrBool{
 							RoutingRuleConfiguration: RoutingRuleConfiguration{
 								Alias: Alias{
-									StringSlice: []string{
-										"foobar.com",
-										"v1.foobar.com",
+									AdvancedAliases: []AdvancedAlias{},
+									StringSliceOrString: stringSliceOrString{
+										StringSlice: []string{
+											"foobar.com",
+											"v1.foobar.com",
+										},
 									},
 								},
 								Path:            aws.String("svc"),
@@ -151,7 +157,9 @@ environments:
 						},
 						Network: NetworkConfig{
 							VPC: vpcConfig{
-								Placement: placementP(PublicSubnetPlacement),
+								Placement: PlacementArgOrString{
+									PlacementString: placementStringP(PublicSubnetPlacement),
+								},
 							},
 						},
 						TaskDefOverrides: []OverrideRule{
@@ -207,7 +215,7 @@ environments:
 										Range: Range{
 											Value: &mockRange,
 										},
-										CPU: &mockPerc,
+										CPU: mockConfig,
 									},
 								},
 							},
@@ -270,7 +278,9 @@ secrets:
 						},
 						Network: NetworkConfig{
 							VPC: vpcConfig{
-								Placement: placementP(PublicSubnetPlacement),
+								Placement: PlacementArgOrString{
+									PlacementString: placementStringP(PublicSubnetPlacement),
+								},
 							},
 						},
 					},
@@ -333,7 +343,9 @@ subscribe:
 						},
 						Network: NetworkConfig{
 							VPC: vpcConfig{
-								Placement: placementP(PublicSubnetPlacement),
+								Placement: PlacementArgOrString{
+									PlacementString: placementStringP(PublicSubnetPlacement),
+								},
 							},
 						},
 						Subscribe: SubscribeConfig{
@@ -389,11 +401,28 @@ type: 'OH NO'
 
 func TestCount_UnmarshalYAML(t *testing.T) {
 	var (
-		mockResponseTime = 500 * time.Millisecond
-		mockRange        = IntRangeBand("1-10")
-		mockCPU          = Percentage(70)
-		mockMem          = Percentage(80)
+		perc               = Percentage(70)
+		timeMinute         = 60 * time.Second
+		mockResponseTime   = 500 * time.Millisecond
+		mockRange          = IntRangeBand("1-10")
+		mockAdvancedConfig = ScalingConfigOrPercentage{
+			ScalingConfig: AdvancedScalingConfig{
+				Value: &perc,
+				Cooldown: Cooldown{
+					ScaleInCooldown:  &timeMinute,
+					ScaleOutCooldown: &timeMinute,
+				},
+			},
+		}
+		mockConfig = ScalingConfigOrPercentage{
+			Value: &perc,
+		}
+		mockCooldown = Cooldown{
+			ScaleInCooldown:  &timeMinute,
+			ScaleOutCooldown: &timeMinute,
+		}
 	)
+
 	testCases := map[string]struct {
 		inContent []byte
 
@@ -410,16 +439,20 @@ func TestCount_UnmarshalYAML(t *testing.T) {
 		"With auto scaling enabled": {
 			inContent: []byte(`count:
   range: 1-10
-  cpu_percentage: 70
-  memory_percentage: 80
+  cpu_percentage:
+    value: 70
+    cooldown:
+      in: 1m
+      out: 1m
+  memory_percentage: 70
   requests: 1000
   response_time: 500ms
 `),
 			wantedStruct: Count{
 				AdvancedCount: AdvancedCount{
 					Range:        Range{Value: &mockRange},
-					CPU:          &mockCPU,
-					Memory:       &mockMem,
+					CPU:          mockAdvancedConfig,
+					Memory:       mockConfig,
 					Requests:     aws.Int(1000),
 					ResponseTime: &mockResponseTime,
 				},
@@ -458,6 +491,9 @@ func TestCount_UnmarshalYAML(t *testing.T) {
     min: 2
     max: 8
     spot_from: 3
+  cooldown:
+    in: 1m
+    out: 1m
   cpu_percentage: 70
 `),
 			wantedStruct: Count{
@@ -469,7 +505,8 @@ func TestCount_UnmarshalYAML(t *testing.T) {
 							SpotFrom: aws.Int(3),
 						},
 					},
-					CPU: &mockCPU,
+					Cooldown: mockCooldown,
+					CPU:      mockConfig,
 				},
 			},
 		},
@@ -490,6 +527,7 @@ func TestCount_UnmarshalYAML(t *testing.T) {
 				// check memberwise dereferenced pointer equality
 				require.Equal(t, tc.wantedStruct.Value, b.Count.Value)
 				require.Equal(t, tc.wantedStruct.AdvancedCount.Range, b.Count.AdvancedCount.Range)
+				require.Equal(t, tc.wantedStruct.AdvancedCount.Cooldown, b.Count.AdvancedCount.Cooldown)
 				require.Equal(t, tc.wantedStruct.AdvancedCount.CPU, b.Count.AdvancedCount.CPU)
 				require.Equal(t, tc.wantedStruct.AdvancedCount.Memory, b.Count.AdvancedCount.Memory)
 				require.Equal(t, tc.wantedStruct.AdvancedCount.Requests, b.Count.AdvancedCount.Requests)
