@@ -18,11 +18,14 @@ var defaultTransformers = []mergo.Transformers{
 	basicTransformer{},
 	imageTransformer{},
 	buildArgsOrStringTransformer{},
+	aliasTransformer{},
 	stringSliceOrStringTransformer{},
 	platformArgsOrStringTransformer{},
+	placementArgOrStringTransformer{},
 	healthCheckArgsOrStringTransformer{},
 	countTransformer{},
 	advancedCountTransformer{},
+	scalingConfigOrPercentageTransformer{},
 	rangeTransformer{},
 	efsConfigOrBoolTransformer{},
 	efsVolumeConfigurationTransformer{},
@@ -97,9 +100,36 @@ func (t buildArgsOrStringTransformer) Transformer(typ reflect.Type) func(dst, sr
 	}
 }
 
+type aliasTransformer struct{}
+
+// Transformer returns custom merge logic for Alias's fields.
+func (t aliasTransformer) Transformer(typ reflect.Type) func(dst, src reflect.Value) error {
+	if typ != reflect.TypeOf(Alias{}) {
+		return nil
+	}
+
+	return func(dst, src reflect.Value) error {
+		dstStruct := dst.Convert(reflect.TypeOf(Alias{})).Interface().(Alias)
+		srcStruct := src.Convert(reflect.TypeOf(Alias{})).Interface().(Alias)
+
+		if len(srcStruct.AdvancedAliases) != 0 {
+			dstStruct.StringSliceOrString = stringSliceOrString{}
+		}
+
+		if !srcStruct.StringSliceOrString.isEmpty() {
+			dstStruct.AdvancedAliases = nil
+		}
+
+		if dst.CanSet() { // For extra safety to prevent panicking.
+			dst.Set(reflect.ValueOf(dstStruct).Convert(typ))
+		}
+		return nil
+	}
+}
+
 type stringSliceOrStringTransformer struct{}
 
-// Transformer returns custom merge logic for stringSliceOrStringTransformer's fields.
+// Transformer returns custom merge logic for stringSliceOrString's fields.
 func (t stringSliceOrStringTransformer) Transformer(typ reflect.Type) func(dst, src reflect.Value) error {
 	if !typ.ConvertibleTo(reflect.TypeOf(stringSliceOrString{})) {
 		return nil
@@ -150,6 +180,32 @@ func (t platformArgsOrStringTransformer) Transformer(typ reflect.Type) func(dst,
 	}
 }
 
+type placementArgOrStringTransformer struct{}
+
+// Transformer returns custom merge logic for placementArgOrString's fields.
+func (t placementArgOrStringTransformer) Transformer(typ reflect.Type) func(dst, src reflect.Value) error {
+	if typ != reflect.TypeOf(PlacementArgOrString{}) {
+		return nil
+	}
+
+	return func(dst, src reflect.Value) error {
+		dstStruct, srcStruct := dst.Interface().(PlacementArgOrString), src.Interface().(PlacementArgOrString)
+
+		if srcStruct.PlacementString != nil {
+			dstStruct.PlacementArgs = PlacementArgs{}
+		}
+
+		if !srcStruct.PlacementArgs.isEmpty() {
+			dstStruct.PlacementString = nil
+		}
+
+		if dst.CanSet() { // For extra safety to prevent panicking.
+			dst.Set(reflect.ValueOf(dstStruct))
+		}
+		return nil
+	}
+}
+
 type healthCheckArgsOrStringTransformer struct{}
 
 // Transformer returns custom merge logic for HealthCheckArgsOrString's fields.
@@ -228,6 +284,32 @@ func (t advancedCountTransformer) Transformer(typ reflect.Type) func(dst, src re
 	}
 }
 
+type scalingConfigOrPercentageTransformer struct{}
+
+// Transformer returns custom merge logic for ScalingConfigOrPercentage's fields.
+func (t scalingConfigOrPercentageTransformer) Transformer(typ reflect.Type) func(dst, src reflect.Value) error {
+	if typ != reflect.TypeOf(ScalingConfigOrPercentage{}) {
+		return nil
+	}
+
+	return func(dst, src reflect.Value) error {
+		dstStruct, srcStruct := dst.Interface().(ScalingConfigOrPercentage), src.Interface().(ScalingConfigOrPercentage)
+
+		if !srcStruct.ScalingConfig.IsEmpty() {
+			dstStruct.Value = nil
+		}
+
+		if srcStruct.Value != nil {
+			dstStruct.ScalingConfig = AdvancedScalingConfig{}
+		}
+
+		if dst.CanSet() { // For extra safety to prevent panicking.
+			dst.Set(reflect.ValueOf(dstStruct))
+		}
+		return nil
+	}
+}
+
 type rangeTransformer struct{}
 
 // Transformer returns custom merge logic for Range's fields.
@@ -338,7 +420,7 @@ func (t routingRuleConfigOrBoolTransformer) Transformer(typ reflect.Type) func(d
 	return func(dst, src reflect.Value) error {
 		dstStruct, srcStruct := dst.Interface().(RoutingRuleConfigOrBool), src.Interface().(RoutingRuleConfigOrBool)
 
-		if !srcStruct.RoutingRuleConfiguration.isEmpty() {
+		if !srcStruct.RoutingRuleConfiguration.IsEmpty() {
 			dstStruct.Enabled = nil
 		}
 
