@@ -1,7 +1,6 @@
 // Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 // SPDX-License-Identifier: Apache-2.0
 
-// Package manifest provides functionality to create Manifest files.
 package manifest
 
 import (
@@ -11,6 +10,7 @@ import (
 	"strings"
 
 	"github.com/aws/copilot-cli/internal/pkg/docker/dockerengine"
+	"github.com/aws/copilot-cli/internal/pkg/template"
 
 	"github.com/google/shlex"
 
@@ -24,25 +24,28 @@ const (
 
 const (
 	// AWS VPC subnet placement options.
-	PublicSubnetPlacement  = Placement("public")
-	PrivateSubnetPlacement = Placement("private")
+	PublicSubnetPlacement  = PlacementString("public")
+	PrivateSubnetPlacement = PlacementString("private")
 )
 
 // All placement options.
-var subnetPlacements = []string{string(PublicSubnetPlacement), string(PrivateSubnetPlacement)}
+var (
+	subnetPlacements = []string{string(PublicSubnetPlacement), string(PrivateSubnetPlacement)}
+)
 
 // Error definitions.
 var (
 	ErrAppRunnerInvalidPlatformWindows = errors.New("Windows is not supported for App Runner services")
 
-	errUnmarshalBuildOpts    = errors.New("unable to unmarshal build field into string or compose-style map")
-	errUnmarshalPlatformOpts = errors.New("unable to unmarshal platform field into string or compose-style map")
-	errUnmarshalCountOpts    = errors.New(`unable to unmarshal "count" field to an integer or autoscaling configuration`)
-	errUnmarshalRangeOpts    = errors.New(`unable to unmarshal "range" field`)
+	errUnmarshalBuildOpts     = errors.New("unable to unmarshal build field into string or compose-style map")
+	errUnmarshalPlatformOpts  = errors.New("unable to unmarshal platform field into string or compose-style map")
+	errUnmarshalPlacementOpts = errors.New("unable to unmarshal placement field into string or compose-style map")
+	errUnmarshalCountOpts     = errors.New(`unable to unmarshal "count" field to an integer or autoscaling configuration`)
+	errUnmarshalRangeOpts     = errors.New(`unable to unmarshal "range" field`)
 
 	errUnmarshalExec       = errors.New(`unable to unmarshal "exec" field into boolean or exec configuration`)
 	errUnmarshalEntryPoint = errors.New(`unable to unmarshal "entrypoint" into string or slice of strings`)
-	errUnmarshalAlias      = errors.New(`unable to unmarshal "alias" into string or slice of strings`)
+	errUnmarshalAlias      = errors.New(`unable to unmarshal "alias" into advanced alias map, string, or slice of strings`)
 	errUnmarshalCommand    = errors.New(`unable to unmarshal "command" into string or slice of strings`)
 )
 
@@ -55,6 +58,7 @@ func WorkloadTypes() []string {
 type WorkloadManifest interface {
 	ApplyEnv(envName string) (WorkloadManifest, error)
 	Validate() error
+	RequiredEnvironmentFeatures() []string
 }
 
 // UnmarshalWorkload deserializes the YAML input stream into a workload manifest object.
@@ -267,6 +271,10 @@ type stringSliceOrString struct {
 	StringSlice []string
 }
 
+func (s *stringSliceOrString) isEmpty() bool {
+	return s.String == nil && len(s.StringSlice) == 0
+}
+
 func unmarshalYAMLToStringSliceOrString(s *stringSliceOrString, value *yaml.Node) error {
 	if err := value.Decode(&s.StringSlice); err != nil {
 		switch err.(type) {
@@ -380,17 +388,67 @@ func (c *NetworkConfig) IsEmpty() bool {
 	return c.VPC.isEmpty()
 }
 
-// Placement represents where to place tasks (public or private subnets).
-type Placement string
+func (c *NetworkConfig) requiredEnvFeatures() []string {
+	if aws.StringValue((*string)(c.VPC.Placement.PlacementString)) == string(PrivateSubnetPlacement) {
+		return []string{template.NATFeatureName}
+	}
+	return nil
+}
+
+// PlacementArgOrString represents where to place tasks.
+type PlacementArgOrString struct {
+	*PlacementString
+	PlacementArgs
+}
+
+// IsEmpty returns empty if the struct has all zero members.
+func (p *PlacementArgOrString) IsEmpty() bool {
+	return p.PlacementString == nil && p.PlacementArgs.isEmpty()
+}
+
+// UnmarshalYAML overrides the default YAML unmarshaling logic for the PlacementArgOrString
+// struct, allowing it to perform more complex unmarshaling behavior.
+// This method implements the yaml.Unmarshaler (v3) interface.
+func (p *PlacementArgOrString) UnmarshalYAML(value *yaml.Node) error {
+	if err := value.Decode(&p.PlacementArgs); err != nil {
+		switch err.(type) {
+		case *yaml.TypeError:
+			break
+		default:
+			return err
+		}
+	}
+	if !p.PlacementArgs.isEmpty() {
+		// Unmarshaled successfully to p.PlacementArgs, unset p.PlacementString, and return.
+		p.PlacementString = nil
+		return nil
+	}
+	if err := value.Decode(&p.PlacementString); err != nil {
+		return errUnmarshalPlacementOpts
+	}
+	return nil
+}
+
+// PlacementArgs represents what subnets to place tasks.
+type PlacementArgs struct {
+	Subnets []string `yaml:"subnets"`
+}
+
+func (p *PlacementArgs) isEmpty() bool {
+	return p.Subnets == nil || len(p.Subnets) == 0
+}
+
+// PlacementString represents what types of subnets (public or private subnets) to place tasks.
+type PlacementString string
 
 // vpcConfig represents the security groups and subnets attached to a task.
 type vpcConfig struct {
-	*Placement     `yaml:"placement"`
-	SecurityGroups []string `yaml:"security_groups"`
+	Placement      PlacementArgOrString `yaml:"placement"`
+	SecurityGroups []string             `yaml:"security_groups"`
 }
 
 func (c *vpcConfig) isEmpty() bool {
-	return c.Placement == nil && c.SecurityGroups == nil
+	return c.Placement.IsEmpty() && c.SecurityGroups == nil
 }
 
 // PlatformArgsOrString is a custom type which supports unmarshaling yaml which
@@ -544,7 +602,7 @@ func uint16P(n uint16) *uint16 {
 	return &n
 }
 
-func placementP(p Placement) *Placement {
+func placementStringP(p PlacementString) *PlacementString {
 	if p == "" {
 		return nil
 	}
