@@ -354,6 +354,41 @@ func TestPlatformArgsOrString_UnmarshalYAML(t *testing.T) {
 	}
 }
 
+func TestPlacementArgOrString_UnmarshalYAML(t *testing.T) {
+	testCases := map[string]struct {
+		inContent []byte
+
+		wantedStruct PlacementArgOrString
+		wantedError  error
+	}{
+		"returns error if both string and args specified": {
+			inContent: []byte(`placement: private
+  subnets: ["id1", "id2"]`),
+
+			wantedError: errors.New("yaml: line 2: mapping values are not allowed in this context"),
+		},
+		"error if unmarshalable": {
+			inContent: []byte(`placement:
+  ohess: linus
+  archie: leg64`),
+			wantedError: errUnmarshalPlacementOpts,
+		},
+	}
+	for name, tc := range testCases {
+		t.Run(name, func(t *testing.T) {
+			v := vpcConfig{}
+			err := yaml.Unmarshal(tc.inContent, &v)
+			if tc.wantedError != nil {
+				require.EqualError(t, err, tc.wantedError.Error())
+			} else {
+				require.NoError(t, err)
+				require.Equal(t, tc.wantedStruct.PlacementString, v.Placement.PlacementString)
+				require.Equal(t, tc.wantedStruct.PlacementArgs.Subnets, v.Placement.PlacementArgs.Subnets)
+			}
+		})
+	}
+}
+
 func TestPlatformArgsOrString_OS(t *testing.T) {
 	linux := PlatformString("linux/amd64")
 	testCases := map[string]struct {
@@ -641,7 +676,9 @@ network:
 `,
 			wantedConfig: &NetworkConfig{
 				VPC: vpcConfig{
-					Placement:      placementP("public"),
+					Placement: PlacementArgOrString{
+						PlacementString: placementStringP(PublicSubnetPlacement),
+					},
 					SecurityGroups: []string{"sg-1234", "sg-4567"},
 				},
 			},
