@@ -69,10 +69,8 @@ func (r *ConfigRunner) Run() ([]*Task, error) {
 		r.Subnets = subnets
 	}
 	platformVersion := "LATEST"
-	enableExec := true
 	if IsValidWindowsOS(r.OS) {
 		platformVersion = "1.0.0"
-		enableExec = false
 	}
 
 	ecsTasks, err := r.Starter.RunTask(ecs.RunTaskInput{
@@ -83,7 +81,7 @@ func (r *ConfigRunner) Run() ([]*Task, error) {
 		TaskFamilyName:  taskFamilyName(r.GroupName),
 		StartedBy:       startedBy,
 		PlatformVersion: platformVersion,
-		EnableExec:      enableExec,
+		EnableExec:      true,
 	})
 	if err != nil {
 		return nil, &errRunTask{
