@@ -95,7 +95,7 @@ func TestWorkspace_Path(t *testing.T) {
 
 			ws := Workspace{
 				workingDir: tc.workingDir,
-				fsUtils:    &afero.Afero{Fs: fs},
+				fs:         &afero.Afero{Fs: fs},
 				copilotDir: tc.presetManifestDir,
 			}
 			workspacePath, err := ws.Path()
@@ -149,7 +149,7 @@ func TestWorkspace_Summary(t *testing.T) {
 
 			ws := Workspace{
 				workingDir: tc.workingDir,
-				fsUtils:    &afero.Afero{Fs: fs},
+				fs:         &afero.Afero{Fs: fs},
 			}
 			summary, err := ws.Summary()
 			if tc.expectedError == nil {
@@ -225,7 +225,7 @@ func TestWorkspace_Create(t *testing.T) {
 
 			ws := Workspace{
 				workingDir: tc.workingDir,
-				fsUtils:    &afero.Afero{Fs: fs},
+				fs:         &afero.Afero{Fs: fs},
 			}
 			err := ws.Create(tc.appName)
 			if tc.expectedError == nil {
@@ -341,7 +341,7 @@ type: Load Balanced Web Service`))
 		t.Run(name, func(t *testing.T) {
 			ws := &Workspace{
 				copilotDir: tc.copilotDir,
-				fsUtils: &afero.Afero{
+				fs: &afero.Afero{
 					Fs: tc.fs(),
 				},
 			}
@@ -435,7 +435,7 @@ type: Load Balanced Web Service`))
 		t.Run(name, func(t *testing.T) {
 			ws := &Workspace{
 				copilotDir: tc.copilotDir,
-				fsUtils: &afero.Afero{
+				fs: &afero.Afero{
 					Fs: tc.fs(),
 				},
 			}
@@ -450,7 +450,7 @@ type: Load Balanced Web Service`))
 	}
 }
 
-func TestWorkspace_ListWorkspaces(t *testing.T) {
+func TestWorkspace_ListWorkloads(t *testing.T) {
 	testCases := map[string]struct {
 		copilotDir string
 		fs         func() afero.Fs
@@ -497,7 +497,7 @@ type: Scheduled Job`))
 		t.Run(name, func(t *testing.T) {
 			ws := &Workspace{
 				copilotDir: tc.copilotDir,
-				fsUtils: &afero.Afero{
+				fs: &afero.Afero{
 					Fs: tc.fs(),
 				},
 			}
@@ -512,6 +512,72 @@ type: Scheduled Job`))
 	}
 }
 
+func TestWorkspace_ListEnvironments(t *testing.T) {
+	testCases := map[string]struct {
+		copilotDir string
+		fs         func() afero.Fs
+
+		wantedNames []string
+		wantedErr   error
+	}{
+		"environments directory does not exist": {
+			copilotDir: "/copilot",
+			fs: func() afero.Fs {
+				fs := afero.NewMemMapFs()
+				fs.Mkdir("/copilot", 0755)
+				return fs
+			},
+			wantedErr: errors.New("read directory /copilot/environments: open /copilot/environments: file does not exist"),
+		},
+		"retrieve only env directories with manifest files": {
+			copilotDir: "/copilot",
+			fs: func() afero.Fs {
+				fs := afero.NewMemMapFs()
+				fs.Mkdir("/copilot", 0755)
+
+				// Environments.
+				fs.Mkdir("/copilot/environments/test", 0755)
+				fs.Create("/copilot/environments/test/manifest.yml")
+
+				fs.Mkdir("/copilot/environments/dev", 0755)
+				fs.Create("/copilot/environments/dev/manifest.yml")
+
+				// Missing manifest.yml.
+				fs.Mkdir("/copilot/environments/prod", 0755)
+
+				// Legacy pipeline files.
+				fs.Create("/copilot/buildspec.yml")
+				fs.Create("/copilot/pipeline.yml")
+
+				// Services.
+				fs.Mkdir("/copilot/frontend", 0755)
+				fs.Create("/copilot/frontend/manifest.yml")
+				return fs
+			},
+
+			wantedNames: []string{"test", "dev"},
+		},
+	}
+
+	for name, tc := range testCases {
+		t.Run(name, func(t *testing.T) {
+			ws := &Workspace{
+				copilotDir: tc.copilotDir,
+				fs: &afero.Afero{
+					Fs: tc.fs(),
+				},
+			}
+
+			names, err := ws.ListEnvironments()
+			if tc.wantedErr != nil {
+				require.EqualError(t, err, tc.wantedErr.Error())
+			} else {
+				require.ElementsMatch(t, tc.wantedNames, names)
+			}
+		})
+	}
+}
+
 func TestWorkspace_ListPipelines(t *testing.T) {
 	testCases := map[string]struct {
 		copilotDir string
@@ -709,7 +775,7 @@ version: 1
 		t.Run(name, func(t *testing.T) {
 			ws := &Workspace{
 				copilotDir: tc.copilotDir,
-				fsUtils: &afero.Afero{
+				fs: &afero.Afero{
 					Fs: tc.fs(),
 				},
 				logger: logCollector,
@@ -804,7 +870,7 @@ func TestWorkspace_ReadAddonsDir(t *testing.T) {
 			// GIVEN
 			ws := &Workspace{
 				copilotDir: tc.copilotDirPath,
-				fsUtils: &afero.Afero{
+				fs: &afero.Afero{
 					Fs: tc.fs(),
 				},
 			}
@@ -859,7 +925,7 @@ func TestWorkspace_WriteAddon(t *testing.T) {
 			ws := &Workspace{
 				workingDir: "/",
 				copilotDir: "/copilot",
-				fsUtils:    utils,
+				fs:         utils,
 			}
 
 			// WHEN
@@ -878,6 +944,181 @@ func TestWorkspace_WriteAddon(t *testing.T) {
 	}
 }
 
+func TestWorkspace_ReadWorkloadManifest(t *testing.T) {
+	const (
+		mockCopilotDir   = "/copilot"
+		mockWorkloadName = "webhook"
+	)
+	testCases := map[string]struct {
+		elems  []string
+		mockFS func() afero.Fs
+
+		wantedData      WorkloadManifest
+		wantedErr       error
+		wantedErrPrefix string
+	}{
+		"return error if directory does not exist": {
+			mockFS: func() afero.Fs {
+				fs := afero.NewMemMapFs()
+				return fs
+			},
+			wantedErr: fmt.Errorf("file /copilot/webhook/manifest.yml does not exists"),
+		},
+		"fail to read name from manifest": {
+			mockFS: func() afero.Fs {
+				fs := afero.NewMemMapFs()
+				fs.MkdirAll("/copilot/webhook/", 0755)
+				f, _ := fs.Create("/copilot/webhook/manifest.yml")
+				defer f.Close()
+				f.Write([]byte(`hello`))
+				return fs
+			},
+			wantedErrPrefix: `unmarshal manifest file to retrieve "name"`,
+		},
+		"name from manifest does not match with dir": {
+			mockFS: func() afero.Fs {
+				fs := afero.NewMemMapFs()
+				fs.MkdirAll("/copilot/webhook/", 0755)
+				f, _ := fs.Create("/copilot/webhook/manifest.yml")
+				defer f.Close()
+				f.Write([]byte(`name: not-webhook`))
+				return fs
+			},
+			wantedErr: errors.New(`name of the manifest "not-webhook" and directory "webhook" do not match`),
+		},
+		"read existing file": {
+			mockFS: func() afero.Fs {
+				fs := afero.NewMemMapFs()
+				fs.MkdirAll("/copilot/webhook/", 0755)
+				f, _ := fs.Create("/copilot/webhook/manifest.yml")
+				defer f.Close()
+				f.Write([]byte(`name: webhook
+type: Load Balanced Web Service
+flavor: vanilla`))
+				return fs
+			},
+
+			wantedData: []byte(`name: webhook
+type: Load Balanced Web Service
+flavor: vanilla`),
+		},
+	}
+	for name, tc := range testCases {
+		t.Run(name, func(t *testing.T) {
+			ws := &Workspace{
+				copilotDir: mockCopilotDir,
+				fs: &afero.Afero{
+					Fs: tc.mockFS(),
+				},
+			}
+			data, err := ws.ReadWorkloadManifest(mockWorkloadName)
+			if tc.wantedErr == nil && tc.wantedErrPrefix == "" {
+				require.NoError(t, err)
+				require.Equal(t, tc.wantedData, data)
+			}
+			if tc.wantedErr != nil {
+				require.EqualError(t, err, tc.wantedErr.Error())
+			}
+			if tc.wantedErrPrefix != "" {
+				require.ErrorContains(t, err, tc.wantedErrPrefix)
+			}
+		})
+	}
+}
+
+func TestWorkspace_ReadEnvironmentManifest(t *testing.T) {
+	const mockEnvironmentName = "test"
+
+	testCases := map[string]struct {
+		elems  []string
+		mockFS func() afero.Fs
+
+		wantedData      EnvironmentManifest
+		wantedErr       error
+		wantedErrPrefix string
+	}{
+		"return error if directory does not exist": {
+			mockFS: func() afero.Fs {
+				fs := afero.NewMemMapFs()
+				return fs
+			},
+			wantedErr: errors.New("file /copilot/environments/test/manifest.yml does not exists"),
+		},
+		"fail to read name from manifest": {
+			mockFS: func() afero.Fs {
+				fs := afero.NewMemMapFs()
+				fs.MkdirAll("/copilot/environments/test/", 0755)
+				f, _ := fs.Create("/copilot/environments/test/manifest.yml")
+				defer f.Close()
+				f.Write([]byte(`hello`))
+				return fs
+			},
+			wantedErrPrefix: `unmarshal manifest file to retrieve "name"`,
+		},
+		"name from manifest does not match with dir": {
+			mockFS: func() afero.Fs {
+				fs := afero.NewMemMapFs()
+				fs.MkdirAll("/copilot/environments/test", 0755)
+				f, _ := fs.Create("/copilot/environments/test/manifest.yml")
+				defer f.Close()
+				f.Write([]byte(`name: not-test`))
+				return fs
+			},
+			wantedErr: errors.New(`name of the manifest "not-test" and directory "test" do not match`),
+		},
+		"type from manifest is not environment": {
+			mockFS: func() afero.Fs {
+				fs := afero.NewMemMapFs()
+				fs.MkdirAll("/copilot/environments/test", 0755)
+				f, _ := fs.Create("/copilot/environments/test/manifest.yml")
+				defer f.Close()
+				f.Write([]byte(`name: test
+type: Load Balanced
+flavor: vanilla`))
+				return fs
+			},
+			wantedErr: errors.New(`manifest test has type of "Load Balanced", not "Environment"`),
+		},
+		"read existing file": {
+			mockFS: func() afero.Fs {
+				fs := afero.NewMemMapFs()
+				fs.MkdirAll("/copilot/environments/test/", 0755)
+				f, _ := fs.Create("/copilot/environments/test/manifest.yml")
+				defer f.Close()
+				f.Write([]byte(`name: test
+type: Environment
+flavor: vanilla`))
+				return fs
+			},
+
+			wantedData: []byte(`name: test
+type: Environment
+flavor: vanilla`),
+		},
+	}
+	for name, tc := range testCases {
+		t.Run(name, func(t *testing.T) {
+			ws := &Workspace{
+				copilotDir: "/copilot",
+				fs: &afero.Afero{
+					Fs: tc.mockFS(),
+				},
+			}
+			data, err := ws.ReadEnvironmentManifest(mockEnvironmentName)
+			if tc.wantedErr == nil && tc.wantedErrPrefix == "" {
+				require.NoError(t, err)
+				require.Equal(t, tc.wantedData, data)
+			}
+			if tc.wantedErr != nil {
+				require.EqualError(t, err, tc.wantedErr.Error())
+			}
+			if tc.wantedErrPrefix != "" {
+				require.ErrorContains(t, err, tc.wantedErrPrefix)
+			}
+		})
+	}
+}
+
 func TestWorkspace_ReadPipelineManifest(t *testing.T) {
 	copilotDir := "/copilot"
 	testCases := map[string]struct {
@@ -929,7 +1170,7 @@ version: 0
 			fs := tc.fs()
 			ws := &Workspace{
 				copilotDir: copilotDir,
-				fsUtils:    &afero.Afero{Fs: fs},
+				fs:         &afero.Afero{Fs: fs},
 			}
 
 			// WHEN
@@ -968,12 +1209,12 @@ func TestWorkspace_DeleteWorkspaceFile(t *testing.T) {
 			fs := tc.fs()
 			ws := &Workspace{
 				copilotDir: tc.copilotDir,
-				fsUtils: &afero.Afero{
+				fs: &afero.Afero{
 					Fs: fs,
 				},
 			}
-			ws.fsUtils.MkdirAll("copilot", 0755)
-			ws.fsUtils.Create(tc.copilotDir + "/" + ".workspace")
+			ws.fs.MkdirAll("copilot", 0755)
+			ws.fs.Create(tc.copilotDir + "/" + ".workspace")
 
 			// WHEN
 			err := ws.DeleteWorkspaceFile()
@@ -1053,7 +1294,7 @@ func TestWorkspace_ListDockerfiles(t *testing.T) {
 			ws := &Workspace{
 				workingDir: "/",
 				copilotDir: "copilot",
-				fsUtils: &afero.Afero{
+				fs: &afero.Afero{
 					Fs: fs,
 				},
 			}
@@ -1111,7 +1352,7 @@ func TestWorkspace_read(t *testing.T) {
 		t.Run(name, func(t *testing.T) {
 			ws := &Workspace{
 				copilotDir: tc.copilotDir,
-				fsUtils: &afero.Afero{
+				fs: &afero.Afero{
 					Fs: tc.fs(),
 				},
 			}
@@ -1161,7 +1402,7 @@ func TestWorkspace_write(t *testing.T) {
 			ws := &Workspace{
 				workingDir: "/",
 				copilotDir: "/copilot",
-				fsUtils:    utils,
+				fs:         utils,
 			}
 
 			// WHEN
